@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2016, OFFIS e.V.
+ *  Copyright (C) 1994-2017, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -87,9 +87,6 @@
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
 #endif
-#ifdef HAVE_GUSI_H
-#include <GUSI.h>
-#endif
 
 #include "dcmtk/ofstd/ofstd.h"
 #include "dcmtk/ofstd/ofconapp.h"
@@ -274,6 +271,12 @@ parseVR(char *&s, DcmEVR &vr)
         vr = EVR_UNKNOWN;
         s += 2;
     }
+    // dcmdump uses "??" in case of "Unknown Tag & Data" and implicit VR
+    else if ((*s == '?') && (*(s + 1) == '?'))
+    {
+        vr = EVR_UNKNOWN;
+        s += 2;
+    }
     else ok = OFFalse;
 
     return ok;
@@ -455,9 +458,8 @@ putFileContentsIntoElement(DcmElement *elem, const char *filename)
         /* read binary file into the buffer */
         if (fread(buf, 1, len, f) != len)
         {
-            char errBuf[256];
             OFLOG_ERROR(dump2dcmLogger, "error reading binary data file: " << filename
-                << ": " << OFStandard::strerror(errno, errBuf, sizeof(errBuf)));
+                << ": " << OFStandard::getLastSystemErrorCode().message());
             ec = EC_CorruptedData;
         }
         else if (evr == EVR_OW)
@@ -526,7 +528,7 @@ insertIntoSet(DcmStack &stack, const E_TransferSyntax xfer, const DcmTagKey &tag
         else if (newTagVR == EVR_pixelItem)
             newElement = new DcmPixelItem(DCM_PixelItemTag);
         else
-            newElementError = newDicomElement(newElement, tag);
+            newElementError = DcmItem::newDicomElementWithVR(newElement, tag);
 
         if (newElementError == EC_Normal)
         {
@@ -785,10 +787,6 @@ readDumpFile(DcmMetaInfo *metaheader, DcmDataset *dataset,
 
 int main(int argc, char *argv[])
 {
-#ifdef HAVE_GUSI_H
-    GUSISetup(GUSIwithSIOUXSockets);
-    GUSISetup(GUSIwithInternetSockets);
-#endif
 
     OFConsoleApplication app(OFFIS_CONSOLE_APPLICATION , "Convert ASCII dump to DICOM file", rcsid);
     OFCommandLine cmd;
