@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2014, OFFIS e.V.
+ *  Copyright (C) 1994-2018, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -29,6 +29,7 @@
 
 
 // forward declarations
+class DcmJsonFormat;
 class DcmInputStream;
 class DcmOutputStream;
 class DcmRepresentationParameter;
@@ -57,6 +58,7 @@ class DCMTK_DCMDATA_EXPORT DcmDataset
 
     /** assignment operator
      *  @param obj the dataset to be copied
+     *  @return reference to this object
      */
     DcmDataset& operator=(const DcmDataset& obj);
 
@@ -141,15 +143,7 @@ class DCMTK_DCMDATA_EXPORT DcmDataset
                        const char *pixelFileName = NULL,
                        size_t *pixelCounter = NULL);
 
-    /** calculate the length of this DICOM element when encoded with the
-     *  given transfer syntax and the given encoding type for sequences.
-     *  For elements, the length includes the length of the tag, length field,
-     *  VR field and the value itself, for items and sequences it returns
-     *  the length of the complete item or sequence including delimitation tags
-     *  if applicable. Never returns undefined length.
-     *  @param xfer transfer syntax for length calculation
-     *  @param enctype sequence encoding type for length calculation
-     *  @return length of DICOM element
+    /** @copydoc DcmObject::calcElementLength()
      */
     Uint32 calcElementLength(const E_TransferSyntax xfer,
                              const E_EncodingType enctype);
@@ -183,6 +177,30 @@ class DCMTK_DCMDATA_EXPORT DcmDataset
                              const E_GrpLenEncoding glenc = EGL_noChange,
                              const Uint32 maxReadLength = DCM_MaxReadLength);
 
+    /** This function reads the information of all attributes which
+     *  are captured in the input stream and captures this information
+     *  in this->elementList, up to the attribute tag stopParsingAtElement.
+     *  Each attribute is represented as an
+     *  element in this list. Having read all information for this
+     *  particular data set or command, this function will also take
+     *  care of group length (according to what is specified in glenc)
+     *  and padding elements (don't change anything).
+     *  @param inStream      The stream which contains the information.
+     *  @param xfer          The transfer syntax which was used to encode
+     *                       the information in inStream.
+     *  @param glenc         Encoding type for group length; specifies what
+     *                       will be done with group length tags.
+     *  @param maxReadLength Maximum read length for reading an attribute value.
+     *  @param stopParsingAtElement parsing of the input stream is stopped when
+     *                       this tag key or any higher tag is encountered.
+     *  @return status, EC_Normal if successful, an error code otherwise
+     */
+    virtual OFCondition readUntilTag(DcmInputStream &inStream,
+                                     const E_TransferSyntax xfer = EXS_Unknown,
+                                     const E_GrpLenEncoding glenc = EGL_noChange,
+                                     const Uint32 maxReadLength = DCM_MaxReadLength,
+                                     const DcmTagKey &stopParsingAtElement = DCM_UndefinedTagKey);
+
     /** write dataset to a stream
      *  @param outStream DICOM output stream
      *  @param oxfer output transfer syntax (EXS_Unknown means use original)
@@ -255,6 +273,28 @@ class DCMTK_DCMDATA_EXPORT DcmDataset
     virtual OFCondition writeXML(STD_NAMESPACE ostream &out,
                                  const size_t flags = 0);
 
+    /** write object in JSON format.
+     *  @param out output stream to which the JSON document is written
+     *  @param format used to format and customize the output
+     *  @return status, EC_Normal if successful, an error code otherwise
+     */
+    virtual OFCondition writeJson(STD_NAMESPACE ostream &out,
+                                  DcmJsonFormat &format);
+
+    /** write object in JSON format.
+     *  @tparam Format the formatter class, e.g. DcmJsonFormatPretty.
+     *    Will be deduced automatically.
+     *  @param out output stream to which the JSON document is written
+     *  @param format used to format and customize the output
+     *  @return status, EC_Normal if successful, an error code otherwise
+     */
+    template<typename Format>
+    OFCondition writeJson(STD_NAMESPACE ostream &out,
+                          Format format)
+    {
+        return writeJson(out, OFstatic_cast(DcmJsonFormat&, format));
+    }
+
     /** load object from a DICOM file.
      *  This method only supports DICOM objects stored as a dataset, i.e. without meta header.
      *  Use DcmFileFormat::loadFile() to load files with meta header.
@@ -273,6 +313,27 @@ class DCMTK_DCMDATA_EXPORT DcmDataset
                                  const E_GrpLenEncoding groupLength = EGL_noChange,
                                  const Uint32 maxReadLength = DCM_MaxReadLength);
 
+    /** load object from a DICOM file, up to the attribute tag stopParsingAtElement.
+     *  This method only supports DICOM objects stored as a dataset, i.e. without meta header.
+     *  Use DcmFileFormat::loadFile() to load files with meta header.
+     *  @param fileName name of the file to load (may contain wide chars if support enabled).
+     *    Since there are various constructors for the OFFilename class, a "char *", "OFString"
+     *    or "wchar_t *" can also be passed directly to this parameter.
+     *  @param readXfer transfer syntax used to read the data (auto detection if EXS_Unknown)
+     *  @param groupLength flag, specifying how to handle the group length tags
+     *  @param maxReadLength maximum number of bytes to be read for an element value.
+     *    Element values with a larger size are not loaded until their value is retrieved
+     *    (with getXXX()) or loadAllDataIntoMemory() is called.
+     *  @param stopParsingAtElement parsing of the input stream is stopped when
+     *                       this tag key or any higher tag is encountered.
+     *  @return status, EC_Normal if successful, an error code otherwise
+     */
+    virtual OFCondition loadFileUntilTag(const OFFilename &fileName,
+                                 const E_TransferSyntax readXfer = EXS_Unknown,
+                                 const E_GrpLenEncoding groupLength = EGL_noChange,
+                                 const Uint32 maxReadLength = DCM_MaxReadLength,
+                                 const DcmTagKey &stopParsingAtElement = DCM_UndefinedTagKey);
+
     /** save object to a DICOM file.
      *  This method only supports DICOM objects stored as a dataset, i.e. without meta header.
      *  Use DcmFileFormat::saveFile() to save files with meta header.
@@ -333,6 +394,17 @@ class DCMTK_DCMDATA_EXPORT DcmDataset
      */
     virtual OFBool checkForSpecificCharacterSet() const { return OFTrue; }
 
+  protected:
+
+    /** perform checks after reading of the dataset is considered complete. The
+     *  idea is that some checks cannot be performed when reading a specific
+     *  element, for different reasons, e.g. the values of other elements have
+     *  to be taken into account.
+     *  @return status, EC_Normal if no problems are found, an error code otherwise
+     */
+    OFCondition doPostReadChecks();
+
+
   private:
 
     /// original transfer syntax of the dataset
