@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2016, OFFIS e.V.
+ *  Copyright (C) 1994-2019, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -70,7 +70,8 @@ const unsigned short OFM_dcmiod   = 29;
 const unsigned short OFM_dcmseg   = 30;
 const unsigned short OFM_dcmfg    = 31;
 const unsigned short OFM_dcmtract = 32;
-
+const unsigned short OFM_dcmpmap  = 33;
+const unsigned short OFM_dcmelekt = 34;
 
 // condition constants
 
@@ -161,6 +162,14 @@ extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_MissingAttribute;
 extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_InternalError;
 /// Invalid character, e.g. non-ASCII character used but no Specific Character Set defined
 extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_InvalidCharacter;
+/// Illegal element with OB or OW Value Representation and undefined length encountered
+extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_UndefinedLengthOBOW;
+/// Illegal VOI LUT Sequence element with OB or OW Value Representation and explicit length encountered
+extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_VOI_LUT_OBOW;
+/// Pixel data in top level dataset in compressed Transfer Syntax uses explicit length (undefined required)
+extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_PixelDataExplLengthIllegal;
+/// Element length is larger than 32-bit length field permits
+extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_ElemLengthExceeds32BitField;
 //@}
 
 // status code constants
@@ -174,5 +183,4 @@ extern DCMTK_DCMDATA_EXPORT const unsigned short EC_CODE_CannotConvertToXML;
 /// error, cannot determine start fragment (of compressed pixel data)
 extern DCMTK_DCMDATA_EXPORT const unsigned short EC_CODE_CannotDetermineStartFragment;
 
-
 #endif /* !DCERROR_H */
