@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2016, OFFIS e.V.
+ *  Copyright (C) 1994-2017, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -27,6 +27,9 @@
 
 #include "dcmtk/dcmdata/dcchrstr.h"
 
+// forward declarations
+class DcmJsonFormat;
+
 
 /** a class representing the DICOM value representation 'Long String' (LO)
  */
@@ -86,7 +89,9 @@ class DCMTK_DCMDATA_EXPORT DcmLongString
      */
     virtual DcmEVR ident() const;
 
-    /** check whether stored value conforms to the VR and to the specified VM
+    /** check whether stored value conforms to the VR and to the specified VM.
+     *  Currently, the VR checker only supports ASCII (ISO_IR 6) and Latin-1 (ISO_IR 100).
+     *  All other specific character sets disable the check of the value representation.
      *  @param vm value multiplicity (according to the data dictionary) to be checked for.
      *    (See DcmElement::checkVM() for a list of valid values.)
      *  @param oldFormat parameter not used for this VR (only for DA, TM)
@@ -105,6 +110,15 @@ class DCMTK_DCMDATA_EXPORT DcmLongString
                                     const unsigned long pos,
                                     OFBool normalize = OFTrue);
 
+    /** write object in JSON format
+     *  @param out output stream to which the JSON document is written
+     *  @param format used to format and customize the output
+     *  @return status, EC_Normal if successful, an error code otherwise
+     */
+    virtual OFCondition writeJson(STD_NAMESPACE ostream &out,
+                                  DcmJsonFormat &format);
+
+
     /* --- static helper functions --- */
 
     /** check whether given string value conforms to the VR "LO" (Long String)
@@ -121,6 +135,12 @@ class DCMTK_DCMDATA_EXPORT DcmLongString
     static OFCondition checkStringValue(const OFString &value,
                                         const OFString &vm = "1-n",
                                         const OFString &charset = "");
+
+protected:
+
+    /** @copydoc DcmCharString::getDelimiterChars()
+     */
+    virtual const OFString& getDelimiterChars() const;
 };
 
 
