@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2013-2016, OFFIS e.V.
+ *  Copyright (C) 2013-2019, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -108,7 +108,7 @@ class DCMTK_DCMDATA_EXPORT DcmOtherDouble
      *  @param flags optional flag used to customize the output (see DCMTypes::XF_xxx)
      *  @return status, EC_Normal if successful, an error code otherwise
      */
-    virtual OFCondition writeXML(STD_NAMESPACE ostream&out,
+    virtual OFCondition writeXML(STD_NAMESPACE ostream &out,
                                  const size_t flags = 0);
 
     /** write object in JSON format to a stream
@@ -116,8 +116,18 @@ class DCMTK_DCMDATA_EXPORT DcmOtherDouble
      *  @param format used to format and customize the output
      *  @return status, EC_Normal if successful, an error code otherwise
      */
-    virtual OFCondition writeJson(STD_NAMESPACE ostream&out,
+    virtual OFCondition writeJson(STD_NAMESPACE ostream &out,
                                   DcmJsonFormat &format);
+
+    /** create an empty Float64 array of given number of double values and set it.
+     *  All array elements are initialized with a value of 0 (using 'memzero').
+     *  @param numDoubles number of double values (64 bit) to be created
+     *  @param doubleVals stores the pointer to the resulting Float64 array
+     *    (set to NULL in case of error)
+     *  @return status, EC_Normal if successful, an error code otherwise
+     */
+    virtual OFCondition createFloat64Array(const Uint32 numDoubles,
+                                           Float64 *&doubleVals);
 };
 
 
