@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2002-2014, OFFIS e.V.
+ *  Copyright (C) 2002-2016, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -185,12 +185,12 @@ OFCondition DcmRLECodecEncoder::encode(
     // create initial pixel sequence
     if (result.good())
     {
-      pixelSequence = new DcmPixelSequence(DcmTag(DCM_PixelData,EVR_OB));
+      pixelSequence = new DcmPixelSequence(DCM_PixelSequenceTag);
       if (pixelSequence == NULL) result = EC_MemoryExhausted;
       else
       {
         // create empty offset table
-        offsetTable = new DcmPixelItem(DcmTag(DCM_Item,EVR_OB));
+        offsetTable = new DcmPixelItem(DCM_PixelItemTag);
         if (offsetTable == NULL) result = EC_MemoryExhausted;
         else pixelSequence->insert(offsetTable);
       }
@@ -212,8 +212,8 @@ OFCondition DcmRLECodecEncoder::encode(
       Uint32 offsetBetweenSamples = 0;
       Uint32 sample = 0;
       Uint32 byte = 0;
-      register Uint32 pixel = 0;
-      register Uint32 columnCounter = 0;
+      Uint32 pixel = 0;
+      Uint32 columnCounter = 0;
 
       DcmRLEEncoder *rleEncoder = NULL;
       Uint32 rleSize = 0;
