@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2011-2013, OFFIS e.V.
+ *  Copyright (C) 2011-2017, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -15,7 +15,7 @@
  *
  *  Author:  Joerg Riesmeier
  *
- *  Purpose: Class for supporting the Specfic Character Set attribute
+ *  Purpose: Class for supporting the Specific Character Set attribute
  *
  */
 
@@ -41,23 +41,37 @@ DcmSpecificCharacterSet::DcmSpecificCharacterSet()
   : SourceCharacterSet(),
     DestinationCharacterSet(),
     DestinationEncoding(),
-    EncodingConverter(),
-    ConversionDescriptors()
+    DefaultEncodingConverter(),
+    EncodingConverters()
 {
 }
 
 
 DcmSpecificCharacterSet::~DcmSpecificCharacterSet()
 {
-    // this frees all previously allocated ressources
-    closeConversionDescriptors();
+    clear();
 }
 
 
 void DcmSpecificCharacterSet::clear()
 {
-    // this also clears all other member variables
-    closeConversionDescriptors();
+    DefaultEncodingConverter.clear();
+    EncodingConverters.clear();
+    SourceCharacterSet.clear();
+    DestinationCharacterSet.clear();
+    DestinationEncoding.clear();
+}
+
+
+DcmSpecificCharacterSet::operator OFBool() const
+{
+    return OFstatic_cast(OFBool, DefaultEncodingConverter);
+}
+
+
+OFBool DcmSpecificCharacterSet::operator!() const
+{
+    return !DefaultEncodingConverter;
 }
 
 
@@ -79,25 +93,34 @@ const OFString &DcmSpecificCharacterSet::getDestinationEncoding() const
 }
 
 
-OFBool DcmSpecificCharacterSet::getTransliterationMode() const
+unsigned DcmSpecificCharacterSet::getConversionFlags() const
 {
-    return EncodingConverter.getTransliterationMode();
+    return DefaultEncodingConverter.getConversionFlags();
 }
 
 
-OFBool DcmSpecificCharacterSet::getDiscardIllegalSequenceMode() const
+OFCondition DcmSpecificCharacterSet::setConversionFlags(const unsigned flags)
 {
-    return EncodingConverter.getDiscardIllegalSequenceMode();
+    if (!EncodingConverters.empty())
+    {
+        /* pass conversion flags to all "encoding converters" */
+        for (T_EncodingConvertersMap::iterator it = EncodingConverters.begin();
+            it != EncodingConverters.end(); ++it)
+        {
+            OFCondition status = it->second.setConversionFlags(flags);
+            if (status.bad())
+                return status;
+        }
+        return EC_Normal;
+    } else return DefaultEncodingConverter.setConversionFlags(flags);
 }
 
 
 OFCondition DcmSpecificCharacterSet::selectCharacterSet(const OFString &fromCharset,
-                                                        const OFString &toCharset,
-                                                        const OFBool transliterate,
-                                                        const OFBool discardIllegal)
+                                                        const OFString &toCharset)
 {
-    // first, make sure that all conversion descriptors are closed
-    closeConversionDescriptors();
+    // first, make sure that all converters are cleared
+    clear();
     // determine the destination encoding (and check whether it is supported at all)
     OFCondition status = determineDestinationEncoding(toCharset);
     if (status.good())
@@ -110,7 +133,7 @@ OFCondition DcmSpecificCharacterSet::selectCharacterSet(const OFString &fromChar
         if (sourceVM == 0)
         {
             // no character set specified, use ASCII
-            status = EncodingConverter.selectEncoding("ASCII", DestinationEncoding);
+            status = DefaultEncodingConverter.selectEncoding("ASCII", DestinationEncoding);
             // output some useful debug information
             if (status.good())
             {
@@ -126,55 +149,19 @@ OFCondition DcmSpecificCharacterSet::selectCharacterSet(const OFString &fromChar
             // multiple character sets specified (code extensions used)
             status = selectCharacterSetWithCodeExtensions(sourceVM);
         }
-        // enable or disable the transliteration mode
-        if (status.good())
-        {
-            status = EncodingConverter.setTransliterationMode(transliterate);
-            if (status.good())
-            {
-                // output some useful debug information
-                if (transliterate)
-                {
-                    DCMDATA_DEBUG("DcmSpecificCharacterSet: Enabled transliteration mode, "
-                        << "i.e. the approximation of similar looking characters will be used");
-                } else {
-                    DCMDATA_DEBUG("DcmSpecificCharacterSet: Disabled transliteration mode, "
-                        << "i.e. the approximation of similar looking characters will not be used");
-                }
-            }
-        }
-        // enable or disable the discard illegal sequence mode
-        if (status.good())
-        {
-            status = EncodingConverter.setDiscardIllegalSequenceMode(discardIllegal);
-            if (status.good())
-            {
-                // output some useful debug information
-                if (discardIllegal)
-                {
-                    DCMDATA_DEBUG("DcmSpecificCharacterSet: Enabled 'discard illegal sequence' mode, "
-                        << "i.e. non-representable characters will be discarded");
-                } else {
-                    DCMDATA_DEBUG("DcmSpecificCharacterSet: Disabled 'discard illegal sequence' mode, "
-                        << "i.e. non-representable characters will not be discarded");
-                }
-            }
-        }
     }
     return status;
 }
 
 
 OFCondition DcmSpecificCharacterSet::selectCharacterSet(DcmItem &dataset,
-                                                        const OFString &toCharset,
-                                                        const OFBool transliterate,
-                                                        const OFBool discardIllegal)
+                                                        const OFString &toCharset)
 {
     OFString fromCharset;
     // check whether Specific Character Set (0008,0005) is present in the given item/dataset
     dataset.findAndGetOFStringArray(DCM_SpecificCharacterSet, fromCharset, OFFalse /*searchIntoSub*/);
     // if missing or empty, the default character set (ASCII) will be used
-    return selectCharacterSet(fromCharset, toCharset, transliterate, discardIllegal);
+    return selectCharacterSet(fromCharset, toCharset);
 }
 
 
@@ -213,14 +200,22 @@ OFCondition DcmSpecificCharacterSet::determineDestinationEncoding(const OFString
     else if (DestinationCharacterSet == "ISO_IR 148")   // Latin alphabet No. 5
         DestinationEncoding = "ISO-8859-9";
     else if (DestinationCharacterSet == "ISO_IR 13")    // Japanese
-        DestinationEncoding = "JIS_X0201";              // - "ISO-IR-13" is not supported by libiconv
+#if DCMTK_ENABLE_CHARSET_CONVERSION == DCMTK_CHARSET_CONVERSION_ICONV
+        DestinationEncoding = "JIS_X0201";              // - the name "ISO-IR-13" is not supported by libiconv
+#else
+        DestinationEncoding = "Shift_JIS";              // - ICU and stdlibc iconv only know "Shift_JIS" (is this mapping correct?)
+#endif
     else if (DestinationCharacterSet == "ISO_IR 166")   // Thai
+#if DCMTK_ENABLE_CHARSET_CONVERSION == DCMTK_CHARSET_CONVERSION_ICU
+        DestinationEncoding = "TIS-620";                // - the name "ISO-IR-166" is not supported by ICU
+#else
         DestinationEncoding = "ISO-IR-166";
+#endif
     else if (DestinationCharacterSet == "ISO_IR 192")   // Unicode in UTF-8 (multi-byte)
         DestinationEncoding = "UTF-8";
     else if (DestinationCharacterSet == "GB18030")      // Chinese (multi-byte)
         DestinationEncoding = "GB18030";
-    else if (DestinationCharacterSet == "GBK")          // Chinese (multi-byte, subset of GB18030)
+    else if (DestinationCharacterSet == "GBK")          // Chinese (multi-byte, subset of "GB 18030")
         DestinationEncoding = "GBK";
     else {
         DestinationEncoding.clear();
@@ -266,14 +261,22 @@ OFCondition DcmSpecificCharacterSet::selectCharacterSetWithoutCodeExtensions()
     else if (SourceCharacterSet == "ISO_IR 148")    // Latin alphabet No. 5
         fromEncoding = "ISO-8859-9";
     else if (SourceCharacterSet == "ISO_IR 13")     // Japanese
-        fromEncoding = "JIS_X0201";                 // - "ISO-IR-13" is not supported by libiconv
+#if DCMTK_ENABLE_CHARSET_CONVERSION == DCMTK_CHARSET_CONVERSION_ICONV
+        fromEncoding = "JIS_X0201";                 // - the name "ISO-IR-13" is not supported by libiconv
+#else
+        fromEncoding = "Shift_JIS";                 // - ICU and stdlibc iconv only know "Shift_JIS" (is this mapping correct?)
+#endif
     else if (SourceCharacterSet == "ISO_IR 166")    // Thai
+#if DCMTK_ENABLE_CHARSET_CONVERSION == DCMTK_CHARSET_CONVERSION_ICU
+        fromEncoding = "TIS-620";                   // - the name "ISO-IR-166" is not supported by ICU
+#else
         fromEncoding = "ISO-IR-166";
+#endif
     else if (SourceCharacterSet == "ISO_IR 192")    // Unicode in UTF-8 (multi-byte)
         fromEncoding = "UTF-8";
     else if (SourceCharacterSet == "GB18030")       // Chinese (multi-byte)
         fromEncoding = "GB18030";
-    else if (SourceCharacterSet == "GBK")           // Chinese (multi-byte, subset of GB18030)
+    else if (SourceCharacterSet == "GBK")           // Chinese (multi-byte, subset of "GB 18030")
         fromEncoding = "GBK";
     else {
         // create an appropriate error code
@@ -286,7 +289,7 @@ OFCondition DcmSpecificCharacterSet::selectCharacterSetWithoutCodeExtensions()
     // check whether an appropriate character encoding has been found
     if (!fromEncoding.empty())
     {
-        status = EncodingConverter.selectEncoding(fromEncoding, DestinationEncoding);
+        status = DefaultEncodingConverter.selectEncoding(fromEncoding, DestinationEncoding);
         // output some useful debug information
         if (status.good())
         {
@@ -309,7 +312,6 @@ OFCondition DcmSpecificCharacterSet::selectCharacterSetWithCodeExtensions(const
     OFBool needsASCII = OFFalse;
     OFBool notFirstValue = OFFalse;
     OFString definedTerm;
-    OFCharacterEncoding::T_Descriptor descriptor;
     unsigned long i = 0;
     while ((i < sourceVM) && status.good())
     {
@@ -368,21 +370,29 @@ OFCondition DcmSpecificCharacterSet::selectCharacterSetWithCodeExtensions(const
         }
         else if (definedTerm == "ISO 2022 IR 13")       // Japanese
         {
-            encodingName = "JIS_X0201";                 // - "ISO-IR-13" is not supported by libiconv
+#if DCMTK_ENABLE_CHARSET_CONVERSION == DCMTK_CHARSET_CONVERSION_ICONV
+            encodingName = "JIS_X0201";                 // - the name "ISO-IR-13" is not supported by libiconv
+#else
+            encodingName = "Shift_JIS";                 // - ICU and stdlibc iconv only know "Shift_JIS" (is this mapping correct?)
+#endif
         }
         else if (definedTerm == "ISO 2022 IR 166")      // Thai
         {
+#if DCMTK_ENABLE_CHARSET_CONVERSION == DCMTK_CHARSET_CONVERSION_ICU
+            encodingName = "TIS-620";                   // - "ISO-IR-166" is not supported by ICU
+#else
             encodingName = "ISO-IR-166";
+#endif
             needsASCII = OFTrue;
         }
         else if (definedTerm == "ISO 2022 IR 87")       // Japanese (multi-byte)
         {
-            encodingName = "ISO-IR-87";
+            encodingName = "ISO-IR-87";                 // - this might generate an error since "ISO-IR-87" is not supported by ICU and stdlibc iconv
             notFirstValue = OFTrue;
         }
         else if (definedTerm == "ISO 2022 IR 159")      // Japanese (multi-byte)
         {
-            encodingName = "ISO-IR-159";
+            encodingName = "ISO-IR-159";                // - this might generate an error since "ISO-IR-159" is not supported by ICU and stdlibc iconv
             notFirstValue = OFTrue;
         }
         else if (definedTerm == "ISO 2022 IR 149")      // Korean (multi-byte)
@@ -415,23 +425,29 @@ OFCondition DcmSpecificCharacterSet::selectCharacterSetWithCodeExtensions(const
         // add descriptor to the map using the defined term as a key
         if (status.good() && !encodingName.empty())
         {
+            OFPair<T_EncodingConvertersMap::iterator,OFBool> conv = EncodingConverters.insert(
+                OFMake_pair(definedTerm, OFCharacterEncoding()));
             // but first check whether this encoding has already been added before
-            if (ConversionDescriptors.find(definedTerm) == ConversionDescriptors.end())
+            if (conv.second)
             {
-                status = EncodingConverter.openDescriptor(descriptor, encodingName, DestinationEncoding);
+                status = conv.first->second.selectEncoding(encodingName, DestinationEncoding);
                 if (status.good())
                 {
-                    ConversionDescriptors[definedTerm] = descriptor;
                     // output some useful debug information
                     DCMDATA_DEBUG("DcmSpecificCharacterSet: Added character set '" << definedTerm
                         << "' (" << encodingName << ") for the conversion to " << DestinationEncoding);
                     // also remember the default descriptor, which refers to the first character set
                     if (i == 0)
                     {
-                        EncodingConverter.ConversionDescriptor = descriptor;
+                        DefaultEncodingConverter = conv.first->second;
                         DCMDATA_TRACE("DcmSpecificCharacterSet: Also selected this character set "
                             << "(i.e. '" << definedTerm << "') as the default one");
                     }
+                } else {
+                    DCMDATA_ERROR("DcmSpecificCharacterSet: '" << definedTerm <<
+                        "' is not supported by the utilized character set conversion library '"
+                        << OFCharacterEncoding::getLibraryVersionString() << '\'');
+                    EncodingConverters.erase(conv.first);
                 }
             } else {
                 DCMDATA_WARN("DcmSpecificCharacterSet: '" << definedTerm << "' is defined more than once "
@@ -440,19 +456,25 @@ OFCondition DcmSpecificCharacterSet::selectCharacterSetWithCodeExtensions(const
         }
         ++i;
     }
-    if (status.good())
+    // add ASCII to the map if needed but not already there
+    if (status.good() && needsASCII)
     {
-        // add ASCII to the map if needed but not already there
-        if (needsASCII && (ConversionDescriptors.find("ISO 2022 IR 6") == ConversionDescriptors.end()))
+        OFPair<T_EncodingConvertersMap::iterator,OFBool> conv = EncodingConverters.insert(
+            OFMake_pair(OFString("ISO 2022 IR 6"), OFCharacterEncoding()));
+        if (conv.second)
         {
-            status = EncodingConverter.openDescriptor(descriptor, "ASCII", DestinationEncoding);
+            status = conv.first->second.selectEncoding("ASCII", DestinationEncoding);
             if (status.good())
             {
-                ConversionDescriptors["ISO 2022 IR 6"] = descriptor;
                 // output some useful debug information
                 DCMDATA_DEBUG("DcmSpecificCharacterSet: Added character set 'ISO 2022 IR 6' (ASCII) "
                     << "for the conversion to " << DestinationEncoding
                     << " (because it is needed for one or more of the previously added character sets)");
+            } else {
+                DCMDATA_ERROR("DcmSpecificCharacterSet: 'ISO 2022 IR 6' is not supported by"
+                    << " the utilized character set conversion library '"
+                    << OFCharacterEncoding::getLibraryVersionString() << '\'');
+                EncodingConverters.erase(conv.first);
             }
         }
     }
@@ -476,12 +498,12 @@ OFCondition DcmSpecificCharacterSet::convertString(const char *fromString,
 {
     OFCondition status = EC_Normal;
     // check whether there are any code extensions at all
-    if ((ConversionDescriptors.size() == 0) || !checkForEscapeCharacter(fromString, fromLength))
+    if (EncodingConverters.empty() || !checkForEscapeCharacter(fromString, fromLength))
     {
         DCMDATA_DEBUG("DcmSpecificCharacterSet: Converting '"
             << convertToLengthLimitedOctalString(fromString, fromLength) << "'");
         // no code extensions according to ISO 2022 used - this is the simple case
-        status = EncodingConverter.convertString(fromString, fromLength, toString, OFTrue /*clearMode*/);
+        status = DefaultEncodingConverter.convertString(fromString, fromLength, toString, OFTrue /*clearMode*/);
     } else {
         if (delimiters.empty())
         {
@@ -497,25 +519,27 @@ OFCondition DcmSpecificCharacterSet::convertString(const char *fromString,
         // particular escape sequences in order to switch between character sets
         toString.clear();
         size_t pos = 0;
+        // some (extended) character sets use more than 1 byte per character
+        // (however, the default character set always uses a single byte)
+        unsigned char bytesPerChar = 1;
         // check whether '=' is a delimiter, as it is used in PN values
         OFBool isFirstGroup = (delimiters.find('=') != OFString_npos);
-        // by default, we expect that '^' and '=' (i.e. their ASCII codes) are valid PN delimiters
+        // by default, we expect that delimiters can be checked by their corresponding ASCII codes
         // (this implies that the default character set is not "ISO 2022 IR 87" or "ISO 2022 IR 159")
-        OFBool checkPNDelimiters = OFTrue;
+        OFBool checkDelimiters = OFTrue;
         const char *firstChar = fromString;
         const char *currentChar = fromString;
         // initially, use the default descriptor
-        OFCharacterEncoding::T_Descriptor descriptor = EncodingConverter.ConversionDescriptor;
+        OFCharacterEncoding converter = DefaultEncodingConverter;
         DCMDATA_TRACE("  Starting with the default character set");
         // iterate over all characters of the string (as long as there is no error)
         while ((pos < fromLength) && status.good())
         {
             const char c0 = *currentChar++;
-            // check for characters ESC, LF, FF, CR or any other specified delimiter
-            // (the PN delimiters '^' and '=' require the default character set or ASCII)
+            // check for characters ESC, HT, LF, FF, CR or any other specified delimiter
             const OFBool isEscape = (c0 == '\033');
-            const OFBool isDelimiter = (c0 == '\012') || (c0 == '\014') || (c0 == '\015') ||
-                ((delimiters.find(c0) != OFString_npos) && (((c0 != '^') && (c0 != '=')) || checkPNDelimiters));
+            const OFBool isDelimiter = checkDelimiters &&
+                ((c0 == '\011') || (c0 == '\012') || (c0 == '\014') || (c0 == '\015') || (delimiters.find(c0) != OFString_npos));
             if (isEscape || isDelimiter)
             {
                 // convert the sub-string (before the delimiter) with the current character set
@@ -525,7 +549,7 @@ OFCondition DcmSpecificCharacterSet::convertString(const char *fromString,
                     // output some debug information
                     DCMDATA_TRACE("    Converting sub-string '"
                         << convertToLengthLimitedOctalString(firstChar, convertLength) << "'");
-                    status = EncodingConverter.convertString(descriptor, firstChar, convertLength, toString, OFFalse /*clearMode*/);
+                    status = converter.convertString(firstChar, convertLength, toString, OFFalse /*clearMode*/);
                     if (status.bad())
                         DCMDATA_TRACE("    -> ERROR: " << status.text());
                 }
@@ -596,7 +620,7 @@ OFCondition DcmSpecificCharacterSet::convertString(const char *fromString,
                         if (pos + escLength < fromLength)
                         {
                             c3 = *currentChar++;
-                            if (c3 == 0x43)                // Korean (multi-byte)
+                            if (c3 == 0x43)                // Korean (single- and multi-byte)
                                 key = "ISO 2022 IR 149";
                             else if (c3 == 0x41)           // Simplified Chinese (multi-byte)
                                 key = "ISO 2022 IR 58";
@@ -624,14 +648,28 @@ OFCondition DcmSpecificCharacterSet::convertString(const char *fromString,
                     if (status.good())
                     {
                         DCMDATA_TRACE("  Switching to character set '" << key << "'");
-                        T_DescriptorMap::const_iterator iter = ConversionDescriptors.find(key);
+                        T_EncodingConvertersMap::const_iterator it = EncodingConverters.find(key);
                         // check whether the descriptor was found in the map, i.e. properly declared in (0008,0005)
-                        if (iter != ConversionDescriptors.end())
+                        if (it != EncodingConverters.end())
                         {
-                            descriptor = iter->second;
+                            converter = it->second;
                             // special case: these Japanese character sets replace the ASCII part (G0 code area),
-                            // so according to DICOM PS 3.5 Section 6.2.1 an explicit switch to the default is required
-                            checkPNDelimiters = (key != "ISO 2022 IR 87") && (key != "ISO 2022 IR 159");
+                            // so according to DICOM PS 3.5 Section 6.2.1.2 an explicit switch to the default is required
+                            checkDelimiters = (key != "ISO 2022 IR 87") && (key != "ISO 2022 IR 159");
+                            // determine number of bytes per character (used by the selected character set)
+                            if ((key == "ISO 2022 IR 87") || (key == "ISO 2022 IR 159") || (key == "ISO 2022 IR 58"))
+                            {
+                                DCMDATA_TRACE("    Now using 2 bytes per character");
+                                bytesPerChar = 2;
+                            }
+                            else if (key == "ISO 2022 IR 149")
+                            {
+                                DCMDATA_TRACE("    Now using 1 or 2 bytes per character");
+                                bytesPerChar = 0;      // special handling for single- and multi-byte
+                            } else {
+                                DCMDATA_TRACE("    Now using 1 byte per character");
+                                bytesPerChar = 1;
+                            }
                         } else {
                             OFOStringStream stream;
                             stream << "Cannot convert character set: Escape sequence refers to character set '" << key << "' that "
@@ -654,7 +692,7 @@ OFCondition DcmSpecificCharacterSet::convertString(const char *fromString,
                 // do not copy the escape sequence to the output
                 firstChar = currentChar;
             }
-            // the LF, FF, CR character or other delimiters (depending on the VR) also cause a switch
+            // the HT, LF, FF, CR character or other delimiters (depending on the VR) also cause a switch
             else if (isDelimiter)
             {
                 // output some debug information
@@ -664,15 +702,23 @@ OFCondition DcmSpecificCharacterSet::convertString(const char *fromString,
                 // don't forget to append the delimiter
                 toString += c0;
                 // use the default descriptor again (see DICOM PS 3.5)
-                if (descriptor != EncodingConverter.ConversionDescriptor)
+                if (converter != DefaultEncodingConverter)
                 {
                     DCMDATA_TRACE("  Switching back to the default character set (because a delimiter was found)");
-                    descriptor = EncodingConverter.ConversionDescriptor;
-                    checkPNDelimiters = OFTrue;
+                    converter = DefaultEncodingConverter;
+                    checkDelimiters = OFTrue;
                 }
                 // start new sub-string after delimiter
                 firstChar = currentChar;
             }
+            // skip remaining bytes of current character (if any)
+            else if (bytesPerChar != 1)
+            {
+                const size_t skipBytes = (bytesPerChar > 0) ? (bytesPerChar - 1) : ((c0 & 0x80) ? 1 : 0);
+                if (pos + skipBytes < fromLength)
+                    currentChar += skipBytes;
+                pos += skipBytes;
+            }
             ++pos;
         }
         if (status.good())
@@ -684,7 +730,7 @@ OFCondition DcmSpecificCharacterSet::convertString(const char *fromString,
                 // output some debug information
                 DCMDATA_TRACE("    Converting remaining sub-string '"
                     << convertToLengthLimitedOctalString(firstChar, convertLength) << "'");
-                status = EncodingConverter.convertString(descriptor, firstChar, convertLength, toString, OFFalse /*clearMode*/);
+                status = converter.convertString(firstChar, convertLength, toString, OFFalse /*clearMode*/);
                 if (status.bad())
                     DCMDATA_TRACE("    -> ERROR: " << status.text());
             }
@@ -708,7 +754,7 @@ OFCondition DcmSpecificCharacterSet::convertString(const char *fromString,
 }
 
 
-OFBool DcmSpecificCharacterSet::isConversionLibraryAvailable()
+OFBool DcmSpecificCharacterSet::isConversionAvailable()
 {
     // just call the appropriate function from the underlying class
     return OFCharacterEncoding::isLibraryAvailable();
@@ -722,37 +768,6 @@ size_t DcmSpecificCharacterSet::countCharactersInUTF8String(const OFString &utf8
 }
 
 
-void DcmSpecificCharacterSet::closeConversionDescriptors()
-{
-    T_DescriptorMap::iterator iter = ConversionDescriptors.begin();
-    T_DescriptorMap::const_iterator last = ConversionDescriptors.end();
-    // iterate over the map of conversion descriptors
-    while (iter != last)
-    {
-        // make sure that the default descriptor is not closed multiple times
-        if (iter->second != EncodingConverter.ConversionDescriptor)
-        {
-            // and close the descriptor
-            if (EncodingConverter.closeDescriptor(iter->second).bad())
-            {
-                DCMDATA_ERROR("DcmSpecificCharacterSet: Cannot close previously allocated "
-                    << "conversion descriptor for '" << iter->first << "'");
-            }
-        }
-        ++iter;
-    }
-    // clear the map
-    ConversionDescriptors.clear();
-    // and close the default descriptor
-    if (EncodingConverter.closeDescriptor(EncodingConverter.ConversionDescriptor).bad())
-        DCMDATA_ERROR("DcmSpecificCharacterSet: Cannot close currently selected conversion descriptor");
-    // also clear the various character set and encoding name variables
-    SourceCharacterSet.clear();
-    DestinationCharacterSet.clear();
-    DestinationEncoding.clear();
-}
-
-
 OFBool DcmSpecificCharacterSet::checkForEscapeCharacter(const char *strValue,
                                                         const size_t strLength) const
 {
