@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2018, OFFIS e.V.
+ *  Copyright (C) 1994-2019, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -157,6 +157,7 @@ static const UIDNameMap uidNameMap[] = {
     { UID_BreastProjectionXRayImageStorageForProcessing,       "BreastProjectionXRayImageStorageForProcessing" },
     { UID_BreastTomosynthesisImageStorage,                     "BreastTomosynthesisImageStorage" },
     { UID_CardiacElectrophysiologyWaveformStorage,             "CardiacElectrophysiologyWaveformStorage" },
+    { UID_CArmPhotonElectronRadiationStorage,                  "CArmPhotonElectronRadiationStorage" },
     { UID_ChestCADSRStorage,                                   "ChestCADSRStorage" },
     { UID_ColonCADSRStorage,                                   "ColonCADSRStorage" },
     { UID_ColorPaletteStorage,                                 "ColorPaletteStorage" },
@@ -229,6 +230,8 @@ static const UIDNameMap uidNameMap[] = {
     { UID_OphthalmicVisualFieldStaticPerimetryMeasurementsStorage, "OphthalmicVisualFieldStaticPerimetryMeasurementsStorage" },
     { UID_ParametricMapStorage,                                "ParametricMapStorage" },
     { UID_PatientRadiationDoseSRStorage,                       "PatientRadiationDoseSRStorage" },
+    { UID_PerformedImagingAgentAdministrationSRStorage,        "PerformedImagingAgentAdministrationSRStorage" },
+    { UID_PlannedImagingAgentAdministrationSRStorage,          "PlannedImagingAgentAdministrationSRStorage" },
     { UID_PositronEmissionTomographyImageStorage,              "PositronEmissionTomographyImageStorage" },
     { UID_ProcedureLogStorage,                                 "ProcedureLogStorage" },
     { UID_ProtocolApprovalStorage,                             "ProtocolApprovalStorage" },
@@ -245,7 +248,10 @@ static const UIDNameMap uidNameMap[] = {
     { UID_RTImageStorage,                                      "RTImageStorage" },
     { UID_RTIonBeamsTreatmentRecordStorage,                    "RTIonBeamsTreatmentRecordStorage" },
     { UID_RTIonPlanStorage,                                    "RTIonPlanStorage" },
+    { UID_RTPhysicianIntentStorage,                            "RTPhysicianIntentStorage" },
     { UID_RTPlanStorage,                                       "RTPlanStorage" },
+    { UID_RTRadiationSetStorage,                               "RTRadiationSetStorage" },
+    { UID_RTSegmentAnnotationStorage,                          "RTSegmentAnnotationStorage" },
     { UID_RTStructureSetStorage,                               "RTStructureSetStorage" },
     { UID_RTTreatmentSummaryRecordStorage,                     "RTTreatmentSummaryRecordStorage" },
     { UID_SecondaryCaptureImageStorage,                        "SecondaryCaptureImageStorage" },
@@ -509,6 +515,7 @@ static const UIDNameMap uidNameMap[] = {
     // Well-known Frame of References
     { UID_ICBM452T1FrameOfReference,                           "ICBM452T1FrameOfReference" },
     { UID_ICBMSingleSubjectMRIFrameOfReference,                "ICBMSingleSubjectMRIFrameOfReference" },
+    { UID_IEC61217FixedCoordinateSystemFrameOfReference,       "IEC61217FixedCoordinateSystemFrameOfReference" },
     { UID_SPM2AVG152PDFrameOfReference,                        "SPM2AVG152PDFrameOfReference" },
     { UID_SPM2AVG152T1FrameOfReference,                        "SPM2AVG152T1FrameOfReference" },
     { UID_SPM2AVG152T2FrameOfReference,                        "SPM2AVG152T2FrameOfReference" },
@@ -586,6 +593,7 @@ const char* dcmAllStorageSOPClassUIDs[] = {
     UID_BreastProjectionXRayImageStorageForProcessing,
     UID_BreastTomosynthesisImageStorage,
     UID_CardiacElectrophysiologyWaveformStorage,
+    UID_CArmPhotonElectronRadiationStorage,
     UID_ChestCADSRStorage,
     UID_ColonCADSRStorage,
     UID_ColorSoftcopyPresentationStateStorage,
@@ -651,6 +659,8 @@ const char* dcmAllStorageSOPClassUIDs[] = {
     UID_OphthalmicVisualFieldStaticPerimetryMeasurementsStorage,
     UID_ParametricMapStorage,
     UID_PatientRadiationDoseSRStorage,
+    UID_PerformedImagingAgentAdministrationSRStorage,
+    UID_PlannedImagingAgentAdministrationSRStorage,
     UID_PositronEmissionTomographyImageStorage,
     UID_ProcedureLogStorage,
     UID_PseudoColorSoftcopyPresentationStateStorage,
@@ -666,7 +676,10 @@ const char* dcmAllStorageSOPClassUIDs[] = {
     UID_RTImageStorage,
     UID_RTIonBeamsTreatmentRecordStorage,
     UID_RTIonPlanStorage,
+    UID_RTPhysicianIntentStorage,
     UID_RTPlanStorage,
+    UID_RTRadiationSetStorage,
+    UID_RTSegmentAnnotationStorage,
     UID_RTStructureSetStorage,
     UID_RTTreatmentSummaryRecordStorage,
     UID_SecondaryCaptureImageStorage,
@@ -881,6 +894,7 @@ const char* dcmLongSCUStorageSOPClassUIDs[] = {
 //  UID_AdvancedBlendingPresentationStateStorage,
 //  UID_BreastProjectionXRayImageStorageForPresentation,
 //  UID_BreastProjectionXRayImageStorageForProcessing,
+//  UID_CArmPhotonElectronRadiationStorage,
 //  UID_CompositingPlanarMPRVolumetricPresentationStateStorage,
 //  UID_ContentAssessmentResultsStorage,
 //  UID_CornealTopographyMapStorage,
@@ -893,8 +907,13 @@ const char* dcmLongSCUStorageSOPClassUIDs[] = {
 //  UID_OphthalmicOpticalCoherenceTomographyEnFaceImageStorage,
 //  UID_ParametricMapStorage,
 //  UID_PatientRadiationDoseSRStorage,
+//  UID_PerformedImagingAgentAdministrationSRStorage,
+//  UID_PlannedImagingAgentAdministrationSRStorage,
 //  UID_RadiopharmaceuticalRadiationDoseSRStorage,
 //  UID_RTBrachyApplicationSetupDeliveryInstructionStorage,
+//  UID_RTPhysicianIntentStorage,
+//  UID_RTRadiationSetStorage,
+//  UID_RTSegmentAnnotationStorage,
 //  UID_SegmentedVolumeRenderingVolumetricPresentationStateStorage,
 //  UID_SimplifiedAdultEchoSRStorage,
 //  UID_TractographyResultsStorage,
@@ -1154,6 +1173,7 @@ static const DcmModalityTable modalities[] = {
     { UID_BreastProjectionXRayImageStorageForProcessing,           "BP",  4096 * 4096 * 2 },
     { UID_BreastTomosynthesisImageStorage,                         "BT",  4096 * 4096 * 2 },
     { UID_CardiacElectrophysiologyWaveformStorage,                 "WVc", 4096 },
+    { UID_CArmPhotonElectronRadiationStorage,                      "RRc", 4096 },
     { UID_ChestCADSRStorage,                                       "SRh", 4096 },
     { UID_ColonCADSRStorage,                                       "SRo", 4096 },
     { UID_ColorPaletteStorage,                                     "CP",  4096 },
@@ -1225,6 +1245,8 @@ static const DcmModalityTable modalities[] = {
     { UID_OphthalmicVisualFieldStaticPerimetryMeasurementsStorage, "OPp", 4096 },
     { UID_ParametricMapStorage,                                    "PM",  256 * 256 * 4 },
     { UID_PatientRadiationDoseSRStorage,                           "SRq", 4096 },
+    { UID_PerformedImagingAgentAdministrationSRStorage,            "SRi", 4096 },
+    { UID_PlannedImagingAgentAdministrationSRStorage,              "SRj", 4096 },
     { UID_PositronEmissionTomographyImageStorage,                  "PI",  512 * 512 * 2 },
     { UID_ProcedureLogStorage,                                     "SRp", 4096 },
     { UID_ProtocolApprovalStorage,                                 "PA",  4096 },
@@ -1242,6 +1264,9 @@ static const DcmModalityTable modalities[] = {
     { UID_RTIonBeamsTreatmentRecordStorage,                        "RTi", 4096 },
     { UID_RTIonPlanStorage,                                        "RPi", 4096 },
     { UID_RTPlanStorage,                                           "RP" , 4096 },
+    { UID_RTPhysicianIntentStorage,                                "RIp", 4096 },
+    { UID_RTRadiationSetStorage,                                   "RRs", 4096 },
+    { UID_RTSegmentAnnotationStorage,                              "RSa", 4096 },
     { UID_RTStructureSetStorage,                                   "RS",  4096 },
     { UID_RTTreatmentSummaryRecordStorage,                         "RTs", 4096 },
     { UID_SecondaryCaptureImageStorage,                            "SC",  512 * 512 * 2 },
