@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2017, OFFIS e.V.
+ *  Copyright (C) 1994-2018, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -76,20 +76,20 @@ int DcmAttributeTag::compare(const DcmElement& rhs) const
     myThis = OFconst_cast(DcmAttributeTag*, this);
     myRhs = OFstatic_cast(DcmAttributeTag*, OFconst_cast(DcmElement*, &rhs));
 
-    /* compare VMs  */
-    unsigned long thisVM = myThis->getVM();
-    unsigned long rhsVM = myRhs->getVM();
-    if (thisVM < rhsVM)
+    /* compare number of values */
+    unsigned long thisNumValues = myThis->getNumberOfValues();
+    unsigned long rhsNumValues = myRhs->getNumberOfValues();
+    if (thisNumValues < rhsNumValues)
     {
         return -1;
     }
-    else if (thisVM > rhsVM)
+    else if (thisNumValues > rhsNumValues)
     {
         return 1;
     }
 
     /* iterate over all components and test equality */
-    for (unsigned long count = 0; count < thisVM; count++)
+    for (unsigned long count = 0; count < thisNumValues; count++)
     {
         DcmTagKey val;
         if (myThis->getTagVal(val, count).good())
@@ -144,6 +144,12 @@ OFCondition DcmAttributeTag::checkValue(const OFString &vm,
 
 
 unsigned long DcmAttributeTag::getVM()
+{
+    return getNumberOfValues();
+}
+
+
+unsigned long DcmAttributeTag::getNumberOfValues()
 {
     /* attribute tags store pairs of 16 bit values */
     return OFstatic_cast(unsigned long, getLengthField() / (2 * sizeof(Uint16)));
@@ -164,7 +170,7 @@ void DcmAttributeTag::print(STD_NAMESPACE ostream& out,
         /* get unsigned integer data */
         Uint16 *uintVals;
         errorFlag = getUint16Array(uintVals);
-        const unsigned long count = getVM();
+        const unsigned long count = getNumberOfValues();
         if ((uintVals != NULL) && (count > 0))
         {
             /* determine number of values to be printed */
