@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2018, OFFIS e.V.
+ *  Copyright (C) 1994-2019, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -25,6 +25,7 @@
 #include "dcmtk/ofstd/ofstd.h"
 #include "dcmtk/ofstd/ofstream.h"
 #include "dcmtk/ofstd/ofuuid.h"
+#include "dcmtk/ofstd/offile.h"
 
 #include "dcmtk/dcmdata/dcjson.h"
 #include "dcmtk/dcmdata/dcvrobow.h"
@@ -165,7 +166,7 @@ OFCondition DcmOtherByteOtherWord::setVR(DcmEVR vr)
 // ********************************
 
 
-void DcmOtherByteOtherWord::print(STD_NAMESPACE ostream&out,
+void DcmOtherByteOtherWord::print(STD_NAMESPACE ostream &out,
                                   const size_t flags,
                                   const int level,
                                   const char * /*pixelFileName*/,
@@ -273,18 +274,20 @@ void DcmOtherByteOtherWord::printPixel(STD_NAMESPACE ostream &out,
                     {
                         swapIfNecessary(EBO_LittleEndian, gLocalByteOrder, data, getLengthField(), sizeof(Uint16));
                         setByteOrder(EBO_LittleEndian);
-                        const size_t count = OFstatic_cast(size_t, getLengthField() / sizeof(Uint16));
-                        if (fwrite(data, sizeof(Uint16), count, file) != count)
-                            DCMDATA_WARN("DcmOtherByteOtherWord: Can't write pixel data to output file: " << fname);
+                        const size_t tobewritten = OFstatic_cast(size_t, getLengthField() / sizeof(Uint16));
+                        const size_t written = fwrite(data, sizeof(Uint16), tobewritten, file);
+                        if (written != tobewritten)
+                            DCMDATA_WARN("DcmOtherByteOtherWord: Some bytes were not written: " << (tobewritten - written));
                     }
                 } else {
                     Uint8 *data = NULL;
                     getUint8Array(data);
                     if (data != NULL)
                     {
-                        const size_t count = OFstatic_cast(size_t, getLengthField());
-                        if (fwrite(data, sizeof(Uint8), count, file) != count)
-                            DCMDATA_WARN("DcmOtherByteOtherWord: Can't write pixel data to output file: " << fname);
+                        const size_t tobewritten = OFstatic_cast(size_t, getLengthField());
+                        const size_t written = fwrite(data, sizeof(Uint8), tobewritten, file);
+                        if (written != tobewritten)
+                            DCMDATA_WARN("DcmOtherByteOtherWord: Some bytes were not written: " << (tobewritten - written));
                     }
                 }
                 fclose(file);
@@ -397,7 +400,14 @@ OFCondition DcmOtherByteOtherWord::createUint16Array(const Uint32 numWords,
 {
     /* check value representation */
     if ((getTag().getEVR() == EVR_OW) || (getTag().getEVR() == EVR_lt))
-        errorFlag = createEmptyValue(OFstatic_cast(Uint32, sizeof(Uint16) * OFstatic_cast(size_t, numWords)));
+    {
+        Uint32 bytesRequired = 0;
+        OFBool size_fits = OFStandard::safeMult(numWords, OFstatic_cast(Uint32, sizeof(Uint16)), bytesRequired);
+        if (size_fits)
+            errorFlag = createEmptyValue(bytesRequired);
+        else
+            errorFlag = EC_CorruptedData;
+    }
     else
         errorFlag = EC_CorruptedData;
     if (errorFlag.good())
