@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2015, Open Connections GmbH
+ *  Copyright (C) 2015-2018, Open Connections GmbH
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation are maintained by
@@ -209,6 +209,8 @@ int FGFrameVOILUT::compare(const FGBase& rhs) const
     return result;
 
   const FGFrameVOILUT* myRhs = OFstatic_cast(const FGFrameVOILUT*, &rhs);
+  if (!myRhs)
+    return -1;
 
   // Compare all elements
   result = m_WindowCenter.compare(myRhs->m_WindowCenter);
