@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2015, Open Connections GmbH
+ *  Copyright (C) 2015-2018, Open Connections GmbH
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation are maintained by
@@ -150,6 +150,8 @@ int FGPlaneOrientationVolume::compare(const FGBase& rhs) const
     return result;
 
   const FGPlaneOrientationVolume* myRhs = OFstatic_cast(const FGPlaneOrientationVolume*, &rhs);
+  if (!myRhs)
+    return -1;
 
   // Compare all elements
   result = m_ImageOrientationVolume.compare(myRhs->m_ImageOrientationVolume);
