@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2015, Open Connections GmbH
+ *  Copyright (C) 2015-2018, Open Connections GmbH
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation are maintained by
@@ -129,6 +129,8 @@ int FGSegmentation::compare(const FGBase& rhs) const
   if (result == 0)
   {
     const FGSegmentation* myRhs = OFstatic_cast(const FGSegmentation*, &rhs);
+    if (!myRhs)
+      return -1;
 
     // Compare all elements
     result = m_ReferencedSegmentNumber.compare(myRhs->m_ReferencedSegmentNumber);
