@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2002-2014, OFFIS e.V.
+ *  Copyright (C) 2002-2016, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -140,8 +140,8 @@ OFCondition DcmQuantColorTable::medianCut(
   for (unsigned int xx=0; xx < numberOfColors; xx++) array[xx] = new DcmQuantHistogramItem();
   numColors = numberOfColors;
 
-  register int i;
-  register unsigned int bi;
+  int i;
+  unsigned int bi;
   DcmQuantPixelBoxArray bv(numberOfColors);
 
   // Set up the initial box.
@@ -153,9 +153,9 @@ OFCondition DcmQuantColorTable::medianCut(
   // Main loop: split boxes until we have enough.
   while ( boxes < numberOfColors )
   {
-      register int indx, clrs;
+      int indx, clrs;
       unsigned long sm;
-      register int minr, maxr, ming, maxg, minb, maxb, v;
+      int minr, maxr, ming, maxg, minb, maxb, v;
       unsigned long halfsum, lowersum;
 
       // Find the first splittable box.
@@ -258,9 +258,9 @@ OFCondition DcmQuantColorTable::medianCut(
   {
       for ( bi = 0; bi < boxes; ++bi )
       {
-          register int indx = bv[bi].ind;
-          register int clrs = bv[bi].colors;
-          register int minr, maxr, ming, maxg, minb, maxb, v;
+          int indx = bv[bi].ind;
+          int clrs = bv[bi].colors;
+          int minr, maxr, ming, maxg, minb, maxb, v;
 
           minr = maxr = histogram.array[indx]->getRed();
           ming = maxg = histogram.array[indx]->getGreen();
@@ -284,9 +284,9 @@ OFCondition DcmQuantColorTable::medianCut(
   {
       for ( bi = 0; bi < boxes; ++bi )
       {
-          register int indx = bv[bi].ind;
-          register int clrs = bv[bi].colors;
-          register long r = 0, g = 0, b = 0;
+          int indx = bv[bi].ind;
+          int clrs = bv[bi].colors;
+          long r = 0, g = 0, b = 0;
 
           for ( i = 0; i < clrs; ++i )
           {
@@ -304,9 +304,9 @@ OFCondition DcmQuantColorTable::medianCut(
   {
       for ( bi = 0; bi < boxes; ++bi )
       {
-          register int indx = bv[bi].ind;
-          register int clrs = bv[bi].colors;
-          register unsigned long r = 0, g = 0, b = 0, sumVal = 0;
+          int indx = bv[bi].ind;
+          int clrs = bv[bi].colors;
+          unsigned long r = 0, g = 0, b = 0, sumVal = 0;
 
           for ( i = 0; i < clrs; ++i )
           {
