@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1999-2010, OFFIS e.V.
+ *  Copyright (C) 1999-2019, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -43,11 +43,7 @@ int main(int argc, char *argv[])
     /* check number of arguments */
     if ((argc >= 3) && (argc <= 4))
     {
-#ifdef HAVE_IOS_NOCREATE
-        STD_NAMESPACE ifstream input(argv[1], STD_NAMESPACE ios::in | STD_NAMESPACE ios::nocreate);
-#else
-        STD_NAMESPACE ifstream input(argv[1], STD_NAMESPACE ios::in);
-#endif
+        STD_NAMESPACE ifstream input(argv[1], OFopenmode_in_nocreate);
         if (input)
         {
             STD_NAMESPACE ofstream output(argv[2]);
