@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2015-2016, Open Connections GmbH
+ *  Copyright (C) 2015-2018, Open Connections GmbH
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation are maintained by
@@ -29,6 +29,8 @@
 #include "dcmtk/dcmdata/dcsequen.h"
 #include "dcmtk/dcmdata/dcdatset.h"
 #include "dcmtk/dcmdata/dcdatutl.h"
+#include "dcmtk/ofstd/ofdate.h"
+#include "dcmtk/ofstd/oftime.h"
 #include "dcmtk/dcmiod/ioddef.h"
 #include "dcmtk/dcmiod/iodrules.h"
 #include "dcmtk/dcmiod/iodtypes.h"
@@ -209,6 +211,7 @@ public:
    *  @param  type Value type (valid value: "1", "1C", "2", something else)
    *  @param  searchCond Optional flag indicating the status of a previous 'search' function call
    *  @param  moduleName Optional module name to be printed (default: "IOD" if NULL)
+   *  @param  logLevel The log level to log errors to
    *  @return EC_Normal if element value is correct, error otherwise
    */
   static OFCondition checkElementValue(const DcmElement *delem,
@@ -216,7 +219,8 @@ public:
                                        const OFString &vm,
                                        const OFString &type,
                                        const OFCondition &searchCond = EC_Normal,
-                                       const char *moduleName = NULL);
+                                       const char *moduleName = NULL,
+                                       const dcmtk::log4cplus::LogLevel logLevel = dcmtk::log4cplus::WARN_LOG_LEVEL);
 
   /** Check element value for correct value multiplicity and type.
    *  @param  delem DICOM element to be checked
@@ -226,13 +230,15 @@ public:
    *  @param  type Value type (valid value: "1", "1C", "2", something else)
    *  @param  searchCond Optional flag indicating the status of a previous 'search' function call
    *  @param  moduleName Optional module name to be printed (default: "IOD" if NULL)
+   *  @param  logLevel The log level to log errors to
    *  @return EC_Normal if element value is correct, error otherwise
    */
   static OFCondition checkElementValue(const DcmElement &delem,
                                        const OFString &vm,
                                        const OFString &type,
                                        const OFCondition &searchCond = EC_Normal,
-                                       const char *moduleName = NULL);
+                                       const char *moduleName = NULL,
+                                       const dcmtk::log4cplus::LogLevel logLevel = dcmtk::log4cplus::WARN_LOG_LEVEL);
 
   /** Get string value from element
    *  @param  delem DICOM element from which the string value should be retrieved
@@ -347,12 +353,12 @@ public:
     if (elem == NULL)
     return EC_IllegalParameter;
 
-    size_t vm = elem->getVM();
+    size_t numValues = elem->getNumberOfValues();
     OFCondition result;
-    for (size_t count = 0; (count < vm) && result.good(); count ++)
+    for (size_t count = 0; (count < numValues) && result.good(); count ++)
     {
       Uint8 value;
-      result = elem->getUint8(value, count);
+      result = elem->getUint8(value, OFstatic_cast(unsigned long, count));
       if ( result.good() )
       {
         destination.push_back(value);
@@ -472,7 +478,7 @@ public:
    *          See DcmElement::checkVM() for a list of valid values.
    *  @param  type The sequence type as noted in part 3 of the DICOM standard,
    *          i.e.\ "1,1C,2,2C or 3".
-   *  @param  module Nname of the module/macro this sequence is contained in. Used
+   *  @param  module Name of the module/macro this sequence is contained in. Used
    *          for error messages and can also be left empty.
    *  @return status EC_Normal if successful, an error code otherwise
    */
@@ -495,15 +501,15 @@ public:
 
 
   /** Reads DICOM sequence into container by creating a dedicated container
-   *   element for each DICOM item. The container must support the
-   *   push_back(T) function and the container's element type T must support
-   *   the read(DcmItem*) function.
-    *  @param  source The source DICOM item read the sequence from
-    *  @param  seqKey The tag key of the sequence to be read
-    *  @param  destination The destination container to read into
-    *  @param  rule The rule for reading this sequence. If NULL, an error is returned.
-    *  @return EC_Normal if successful, an error code otherwise
-    */
+   *  element for each DICOM item. The container must support the
+   *  push_back(T) function and the container's element type T must support
+   *  the read(DcmItem*) function.
+   *  @param  source The source DICOM item read the sequence from
+   *  @param  seqKey The tag key of the sequence to be read
+   *  @param  destination The destination container to read into
+   *  @param  rule The rule for reading this sequence. If NULL, an error is returned.
+   *  @return EC_Normal if successful, an error code otherwise
+   */
   template <class Container>
   static OFCondition readSubSequence(DcmItem& source,
                                      const DcmTagKey& seqKey,
@@ -542,7 +548,7 @@ public:
   {
     OFCondition result;
     /* Check sequence, reports cardinality and type errors as warnings */
-    checkSubSequence(result, source, seqKey, "1", type, module);
+    checkSubSequence(result, source, seqKey, "1", type, module, dcmtk::log4cplus::WARN_LOG_LEVEL);
 
     /* Try to read sequence into internal data (ignore errors as much as possible) */
     DcmItem* item = NULL;
@@ -600,7 +606,6 @@ public:
    *          i.e.\ "1,1C,2,2C or 3".
    *  @param  module Name of the module/macro this sequence is contained in. Used
    *                 for error messages and can also be left empty.
-   *  @return EC_Normal if successful, an error code otherwise
    */
   template <class Container>
   static void writeSubSequence(OFCondition& result,
@@ -636,6 +641,7 @@ public:
               if ( result.bad() )
               {
                   destination.findAndDeleteSequenceItem(seqKey, -1 /* last */);
+                  DCMIOD_ERROR("Could not write item #" << count << " in " << DcmTag(seqKey).getTagName() << ": " << result.text());
               }
             }
             else
@@ -658,7 +664,7 @@ public:
       }
 
       // Check result
-      checkSubSequence(result, destination, seqKey, cardinality, type, module);
+      checkSubSequence(result, destination, seqKey, cardinality, type, module, dcmtk::log4cplus::ERROR_LOG_LEVEL);
 
       // Clean up if we did not have success */
       if (result.bad())
@@ -680,7 +686,6 @@ public:
    *  @param  rule Rule describing the requirements for this sequence. If NULL
    *          an error is returned (IOD_EC_NoSuchRule), but no error error is reported
    *          to the logger.
-   *  @return EC_Normal if successful, an error code otherwise
    */
   template <class Container>
   static void writeSubSequence(OFCondition& result,
@@ -717,7 +722,6 @@ public:
    *          i.e.\ "1,1C,2,2C or 3".
    *  @param  module Name of the module/macro this sequence is contained in.
    *          Used for error messages and can also be left empty.
-   *  @return EC_Normal if successful, an error code otherwise
    */
   template <class Container>
   static void writeSingleItem(OFCondition& result,
@@ -755,14 +759,18 @@ public:
       /* If we do not have data, insert empty for type 2 */
       else if (type == "2")
       {
-          destination.insertEmptyElement(seqKey);
+        destination.insertEmptyElement(seqKey);
       }
       else if (type == "1C")
       {
         DCMIOD_TRACE("Skipping type 1C sequence " << seqKey << ": No data or incomplete data available");
       }
+      else if (type  == "3")
+      {
+        DCMIOD_TRACE("Skipping type 3 sequence " << seqKey << ": No data or incomplete data available");
+      }
       /* Check outcome */
-      checkSubSequence(result, destination, seqKey, "1", type, module);
+      checkSubSequence(result, destination, seqKey, "1", type, module, dcmtk::log4cplus::ERROR_LOG_LEVEL);
     }
   }
 
@@ -777,7 +785,6 @@ public:
    *  @param  destination The DICOM item that should hold the sequence
    *          (with a single item) in the end.
    *  @param  rule The rule for writing the given sequence
-   *  @return EC_Normal if successful, an error code otherwise
    */
   template <class Container>
   static void writeSingleItem(OFCondition& result,
@@ -793,7 +800,10 @@ public:
         DCMIOD_ERROR("Cannot write sequence " << seqKey << " (no rule supplied)");
         result = EC_CannotCheck;
       }
-      writeSingleItem(result, seqKey, source, destination, rule->getType(), rule->getModule());
+      else
+      {
+        writeSingleItem(result, seqKey, source, destination, rule->getType(), rule->getModule());
+      }
     }
   }
 
@@ -811,14 +821,15 @@ public:
    *          i.e.\ "1,1C,2,2C or 3".
    *  @param  module Name of the module/macro this sequence is contained in.
    *          Used for error messages and can also be left empty.
-   *  @return EC_Normal if successful, an error code otherwise
+   *  @param  logLevel The log level to write errors to
    */
   static void checkSubSequence(OFCondition& result,
                                DcmItem& surroundingItem,
                                const DcmTagKey& seqKey,
                                const OFString& cardinality,
                                const OFString& type,
-                               const OFString& module);
+                               const OFString& module,
+                               const dcmtk::log4cplus::LogLevel logLevel);
 
   /** Deletes all elements from given container and calls "delete" on each
    *  of them to clear memory.
@@ -864,6 +875,26 @@ public:
     }
   }
 
+
+  template <typename ModuleType>
+  static OFCondition setContentDateAndTimeNow(ModuleType& module)
+  {
+    OFDate date;
+    date.setCurrentDate();
+    OFString tempstr;
+    date.getISOFormattedDate(tempstr, OFFalse /* no delimiters */);
+    OFCondition result = module.setContentDate(tempstr);
+    if (result.good())
+    {
+      OFTime time;
+      time.setCurrentTime();
+      time.getISOFormattedTime(tempstr, OFTrue /* include seconds */, OFFalse, OFFalse, OFFalse);
+      result = module.setContentTime(tempstr);
+    }
+    return result;
+  }
+
+
   /** Function that takes a string representation of a tag key and
    *  converts it to a tag key instance if possible
    *  @param  keyString String of the format "(gggg,eeee)"
@@ -887,6 +918,20 @@ public:
     */
   static OFString createUID(const Uint8 level = 0);
 
+  /** Print warning if more than 2147483647 frames are present. This is the maximum
+   *  number since the Number of Frames attribute has a VR of IS which allows
+   *  a maximum of 2^31-1.
+   *  The method returns the number of frames that can be used, i.e. either
+   *  2147483647 if the maximum is exceeded, otherwise the actual number
+   *  of frames.
+   *  @param  numFramesPresent The number of frames actually present
+   *  @param  warning The message to be printed if Number of Frames
+   *          is larger than 2147483647.
+   *  @return Number of frames that can be safely used.
+   */
+  static Uint32 limitMaxFrames(const size_t numFramesPresent,
+                               const OFString& warning);
+
 private:
 
   // We only have static functions so we do not need an instance of
