@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2015-2016, Open Connections GmbH
+ *  Copyright (C) 2015-2017, Open Connections GmbH
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation are maintained by
@@ -27,6 +27,15 @@
 #include "dcmtk/dcmdata/dcdeftag.h"
 
 
+IODComponent::IODComponent(const IODComponent& rhs)
+: m_Item(OFstatic_cast(DcmItem*, rhs.m_Item->clone()))
+, m_Rules(rhs.m_Rules->clone())
+, m_Parent(OFnullptr)
+{
+
+}
+
+
 IODComponent::IODComponent(OFshared_ptr<DcmItem> item,
                            OFshared_ptr<IODRules> rules,
                            IODComponent* parent)
@@ -62,24 +71,14 @@ IODComponent& IODComponent::operator=(const IODComponent& rhs)
 {
   if (&rhs != this)
   {
-    m_Rules.reset( rhs.m_Rules->clone() );
-    m_Item.reset( OFstatic_cast(DcmItem*, rhs.m_Item->clone()) );
-    m_Parent = NULL;
+    m_Item.reset(OFstatic_cast(DcmItem*, rhs.m_Item->clone()));
+    m_Rules.reset(rhs.m_Rules->clone());
+    m_Parent = OFnullptr;
   }
   return *this;
 }
 
 
-IODComponent::IODComponent(const IODComponent& rhs)
-{
-
-  if (this == &rhs)
-    return;
-
-  *this = rhs;
-}
-
-
 void IODComponent::inventMissing()
 {
   // Try to fill in missing type 1 information
@@ -95,7 +94,7 @@ void IODComponent::inventMissing()
       DcmElement *elem = NULL;
       if ( getData().findAndGetElement( (*rule)->getTagKey(), elem ).bad() )
       {
-        elem = newDicomElement((*rule)->getTagKey());
+        elem = DcmItem::newDicomElement((*rule)->getTagKey());
         if (elem == NULL)
         {
           DCMIOD_ERROR("Could not allocate element " << (*rule)->getTagKey());
@@ -141,7 +140,7 @@ void IODComponent::makeOptional()
 
 
 OFCondition IODComponent::read(DcmItem& source,
-                               OFBool clearOldData)
+                               const OFBool clearOldData)
 {
   // Debug
   DCMIOD_DEBUG("Reading component: " << getName());
@@ -212,8 +211,8 @@ OFCondition IODComponent::read(DcmItem& source,
     if (isSequence)
     {
       DcmElement *elem = NULL;
-      source.findAndGetElement( (*rule)->getTagKey(), elem);
-      DcmIODUtil::checkElementValue(elem, (*rule)->getTagKey(), (*rule)->getVM(), (*rule)->getType(), EC_Normal, (*rule)->getModule().c_str());
+      OFCondition cond = source.findAndGetElement( (*rule)->getTagKey(), elem);
+      DcmIODUtil::checkElementValue(elem, (*rule)->getTagKey(), (*rule)->getVM(), (*rule)->getType(), cond, (*rule)->getModule().c_str(), dcmtk::log4cplus::WARN_LOG_LEVEL);
     }
     else // Normal attributes are checked and copied over into this IOD component
     {
@@ -265,9 +264,28 @@ IODModule::IODModule(): IODComponent()
 }
 
 
+IODModule::IODModule(const IODModule& rhs)
+: IODComponent(rhs.m_Item, rhs.m_Rules, rhs.m_Parent)
+{
+
+}
+
+
 IODModule::IODModule(OFshared_ptr< DcmItem > item,
   OFshared_ptr< IODRules > rules)
 : IODComponent(item, rules, NULL /* No parent for modules */)
 {
   // nothing to do, IODComponent does the work
 }
+
+
+IODModule& IODModule::operator=(const IODModule& rhs)
+{
+  if (this != &rhs)
+  {
+    m_Item = rhs.m_Item;
+    m_Rules = rhs.m_Rules;
+    m_Parent = rhs.m_Parent;
+  }
+  return *this;
+}
