@@ -98,7 +98,7 @@
 
 METHODDEF(void)
 jpeg_undifference1(j_decompress_ptr cinfo, int comp_index,
-           JDIFFROW diff_buf, JDIFFROW prev_row,
+           const JDIFFROW diff_buf, const JDIFFROW prev_row,
            JDIFFROW undiff_buf, JDIMENSION width)
 {
   UNDIFFERENCE_1D(INITIAL_PREDICTOR2);
@@ -106,7 +106,7 @@ jpeg_undifference1(j_decompress_ptr cinfo, int comp_index,
 
 METHODDEF(void)
 jpeg_undifference2(j_decompress_ptr cinfo, int comp_index,
-           JDIFFROW diff_buf, JDIFFROW prev_row,
+           const JDIFFROW diff_buf, const JDIFFROW prev_row,
            JDIFFROW undiff_buf, JDIMENSION width)
 {
   UNDIFFERENCE_2D(PREDICTOR2);
@@ -116,7 +116,7 @@ jpeg_undifference2(j_decompress_ptr cinfo, int comp_index,
 
 METHODDEF(void)
 jpeg_undifference3(j_decompress_ptr cinfo, int comp_index,
-           JDIFFROW diff_buf, JDIFFROW prev_row,
+           const JDIFFROW diff_buf, const JDIFFROW prev_row,
            JDIFFROW undiff_buf, JDIMENSION width)
 {
   UNDIFFERENCE_2D(PREDICTOR3);
@@ -126,7 +126,7 @@ jpeg_undifference3(j_decompress_ptr cinfo, int comp_index,
 
 METHODDEF(void)
 jpeg_undifference4(j_decompress_ptr cinfo, int comp_index,
-           JDIFFROW diff_buf, JDIFFROW prev_row,
+           const JDIFFROW diff_buf, const JDIFFROW prev_row,
            JDIFFROW undiff_buf, JDIMENSION width)
 {
   UNDIFFERENCE_2D(PREDICTOR4);
@@ -136,7 +136,7 @@ jpeg_undifference4(j_decompress_ptr cinfo, int comp_index,
 
 METHODDEF(void)
 jpeg_undifference5(j_decompress_ptr cinfo, int comp_index,
-           JDIFFROW diff_buf, JDIFFROW prev_row,
+           const JDIFFROW diff_buf, const JDIFFROW prev_row,
            JDIFFROW undiff_buf, JDIMENSION width)
 {
   SHIFT_TEMPS
@@ -147,7 +147,7 @@ jpeg_undifference5(j_decompress_ptr cinfo, int comp_index,
 
 METHODDEF(void)
 jpeg_undifference6(j_decompress_ptr cinfo, int comp_index,
-           JDIFFROW diff_buf, JDIFFROW prev_row,
+           const JDIFFROW diff_buf, const JDIFFROW prev_row,
            JDIFFROW undiff_buf, JDIMENSION width)
 {
   SHIFT_TEMPS
@@ -158,7 +158,7 @@ jpeg_undifference6(j_decompress_ptr cinfo, int comp_index,
 
 METHODDEF(void)
 jpeg_undifference7(j_decompress_ptr cinfo, int comp_index,
-           JDIFFROW diff_buf, JDIFFROW prev_row,
+           const JDIFFROW diff_buf, const JDIFFROW prev_row,
            JDIFFROW undiff_buf, JDIMENSION width)
 {
   SHIFT_TEMPS
@@ -177,7 +177,7 @@ jpeg_undifference7(j_decompress_ptr cinfo, int comp_index,
 
 METHODDEF(void)
 jpeg_undifference_first_row(j_decompress_ptr cinfo, int comp_index,
-                JDIFFROW diff_buf, JDIFFROW prev_row,
+                const JDIFFROW diff_buf, JDIFFROW prev_row,
                 JDIFFROW undiff_buf, JDIMENSION width)
 {
   j_lossless_d_ptr losslsd = (j_lossless_d_ptr) cinfo->codec;
