@@ -33,9 +33,23 @@
  */
 
 #define JPEG_INTERNALS
+#include "dcmtk/config/osconfig.h"
 #include "jinclude16.h"
 #include "jpeglib16.h"
 
+/* check if we have a 64-bit integer type */
+#if SIZEOF_LONG == 8
+typedef long jdmerge_sint64;
+#elif defined(_WIN32)
+typedef __int64 jdmerge_sint64;
+#elif defined(HAVE_LONG_LONG)
+typedef long long jdmerge_sint64;
+#elif defined (HAVE_LONGLONG)
+typedef longlong jdmerge_sint64;
+#else
+#define JDMERGE_NO_SINT64
+#endif
+
 #ifdef UPSAMPLE_MERGING_SUPPORTED
 
 
@@ -103,12 +117,21 @@ build_ycc_rgb_table (j_decompress_ptr cinfo)
   for (i = 0, x = -CENTERJSAMPLE; i <= MAXJSAMPLE; i++, x++) {
     /* i is the actual input pixel value, in the range 0..MAXJSAMPLE */
     /* The Cb or Cr value we are thinking of is x = i - CENTERJSAMPLE */
+#ifdef JDMERGE_NO_SINT64
     /* Cr=>R value is nearest int to 1.40200 * x */
     upsample->Cr_r_tab[i] = (int)
             RIGHT_SHIFT(FIX(1.40200) * x + ONE_HALF, SCALEBITS);
     /* Cb=>B value is nearest int to 1.77200 * x */
     upsample->Cb_b_tab[i] = (int)
             RIGHT_SHIFT(FIX(1.77200) * x + ONE_HALF, SCALEBITS);
+#else
+    /* Cr=>R value is nearest int to 1.40200 * x */
+    upsample->Cr_r_tab[i] = (int)
+            RIGHT_SHIFT((jdmerge_sint64) FIX(1.40200) * x + ONE_HALF, SCALEBITS);
+    /* Cb=>B value is nearest int to 1.77200 * x */
+    upsample->Cb_b_tab[i] = (int)
+            RIGHT_SHIFT((jdmerge_sint64) FIX(1.77200) * x + ONE_HALF, SCALEBITS);
+#endif
     /* Cr=>G value is scaled-up -0.71414 * x */
     upsample->Cr_g_tab[i] = (- FIX(0.71414)) * x;
     /* Cb=>G value is scaled-up -0.34414 * x */
