@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2007-2017, OFFIS e.V.
+ *  Copyright (C) 2007-2019, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -71,15 +71,12 @@ int main(int argc, char *argv[])
   // JPEG-LS encoding options
   E_TransferSyntax opt_oxfer = EXS_JPEGLSLossless;
   OFBool opt_useLosslessProcess = OFTrue;
+  OFBool opt_useFFpadding = OFTrue;
 
-  OFCmdUnsignedInt opt_t1 = 3;
-  OFCmdUnsignedInt opt_t2 = 7;
-  OFCmdUnsignedInt opt_t3 = 21;
-
-  OFCmdUnsignedInt opt_reset = 64;
-  OFCmdUnsignedInt opt_limit = 0;
-
-  OFBool opt_use_custom_options = OFFalse;
+  OFCmdUnsignedInt opt_t1 = 0;
+  OFCmdUnsignedInt opt_t2 = 0;
+  OFCmdUnsignedInt opt_t3 = 0;
+  OFCmdUnsignedInt opt_reset = 0;
 
   // JPEG-LS options
   OFCmdUnsignedInt opt_nearlossless_deviation = 2;
@@ -152,13 +149,14 @@ LICENSE_FILE_DECLARE_COMMAND_LINE_OPTIONS
                                                           "set JPEG-LS encoding parameter threshold 3");
       cmd.addOption("--reset",                  "+rs", 1, "[r]eset: integer (default: 64)",
                                                           "set JPEG-LS encoding parameter reset");
-      cmd.addOption("--limit",                  "+lm", 1, "[l]imit: integer (default: 0)",
-                                                          "set JPEG-LS encoding parameter limit");
     cmd.addSubGroup("JPEG-LS interleave:");
       cmd.addOption("--interleave-line",        "+il",    "force line-interleaved JPEG-LS images (default)");
       cmd.addOption("--interleave-sample",      "+is",    "force sample-interleaved JPEG-LS images");
       cmd.addOption("--interleave-none",        "+in",    "force uninterleaved JPEG-LS images");
       cmd.addOption("--interleave-default",     "+iv",    "use the fastest possible interleave mode");
+    cmd.addSubGroup("JPEG-LS padding of odd-length bitstreams:");
+      cmd.addOption("--padding-standard",       "+ps",    "pad with extended EOI marker (default)");
+      cmd.addOption("--padding-zero",           "+pz",    "pad with zero byte (non-standard)");
 
   cmd.addGroup("encapsulated pixel data encoding options:");
     cmd.addSubGroup("pixel data fragmentation:");
@@ -294,27 +292,18 @@ LICENSE_FILE_EVALUATE_COMMAND_LINE_OPTIONS
       if (cmd.findOption("--threshold1"))
       {
         app.checkValue(cmd.getValueAndCheckMin(opt_t1, OFstatic_cast(OFCmdUnsignedInt, 1)));
-        opt_use_custom_options = OFTrue;
       }
       if (cmd.findOption("--threshold2"))
       {
         app.checkValue(cmd.getValueAndCheckMin(opt_t2, OFstatic_cast(OFCmdUnsignedInt, 1)));
-        opt_use_custom_options = OFTrue;
       }
       if (cmd.findOption("--threshold3"))
       {
         app.checkValue(cmd.getValueAndCheckMin(opt_t3, OFstatic_cast(OFCmdUnsignedInt, 1)));
-        opt_use_custom_options = OFTrue;
       }
       if (cmd.findOption("--reset"))
       {
         app.checkValue(cmd.getValueAndCheckMin(opt_reset, OFstatic_cast(OFCmdUnsignedInt, 1)));
-        opt_use_custom_options = OFTrue;
-      }
-      if (cmd.findOption("--limit"))
-      {
-        app.checkValue(cmd.getValue(opt_limit));
-        opt_use_custom_options = OFTrue;
       }
       cmd.endOptionBlock();
 
@@ -338,6 +327,18 @@ LICENSE_FILE_EVALUATE_COMMAND_LINE_OPTIONS
       }
       cmd.endOptionBlock();
 
+      // padding
+      cmd.beginOptionBlock();
+      if (cmd.findOption("--padding-standard"))
+      {
+        opt_useFFpadding = OFTrue;
+      }
+      if (cmd.findOption("--padding-zero"))
+      {
+        opt_useFFpadding = OFFalse;
+      }
+      cmd.endOptionBlock();
+
       // encapsulated pixel data encoding options
       // pixel data fragmentation options
       cmd.beginOptionBlock();
@@ -404,11 +405,11 @@ LICENSE_FILE_EVALUATE_COMMAND_LINE_OPTIONS
     OFLOG_DEBUG(dcmcjplsLogger, rcsid << OFendl);
 
     // register global compression codecs
-    DJLSEncoderRegistration::registerCodecs(opt_use_custom_options,
+    DJLSEncoderRegistration::registerCodecs(
       OFstatic_cast(Uint16, opt_t1), OFstatic_cast(Uint16, opt_t2), OFstatic_cast(Uint16, opt_t3),
-      OFstatic_cast(Uint16, opt_reset), OFstatic_cast(Uint16, opt_limit),
+      OFstatic_cast(Uint16, opt_reset),
       opt_prefer_cooked, opt_fragmentSize, opt_createOffsetTable,
-      opt_uidcreation, opt_secondarycapture, opt_interleaveMode);
+      opt_uidcreation, opt_secondarycapture, opt_interleaveMode, opt_useFFpadding);
 
     /* make sure data dictionary is loaded */
     if (!dcmDataDict.isDictionaryLoaded())
