@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2009-2017, OFFIS e.V.
+ *  Copyright (C) 2009-2018, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -32,10 +32,6 @@
 #include "dcmtk/dcmnet/scpcfg.h"
 #include "dcmtk/dcmnet/diutil.h"    /* for DCMNET_WARN() */
 
-#ifdef WITH_ZLIB
-#include <zlib.h>     /* for zlibVersion() */
-#endif
-
 
 // include this file in doxygen documentation
 
@@ -83,6 +79,8 @@ enum DcmRefuseReasonType
   DCMSCP_CANNOT_FORK,
   /// Refusing association because of bad application context name
   DCMSCP_BAD_APPLICATION_CONTEXT_NAME,
+  /// Refusing association because of disallowed connecting host
+  DCMSCP_CALLING_HOST_NOT_ALLOWED,
   /// Refusing association because of unaccepted called AE title
   DCMSCP_CALLED_AE_TITLE_NOT_RECOGNIZED,
   /// Refusing association because of unaccepted calling AE title
@@ -128,10 +126,15 @@ struct DCMTK_DCMNET_EXPORT DcmPresentationContextInfo
 
 /** Base class for implementing a DICOM Service Class Provider (SCP). Derived classes can
  *  add the presentation contexts they want to support, set further parameters (port, peer
- *  hostname, etc. as desired) and then call DcmSCP's listen() method to start the server.
+ *  host name, etc. as desired) and then call DcmSCP's listen() method to start the server.
  *  For incoming associations and DIMSE messages, a derived class can define the behavior
- *  of the server. The DcmSCP base class is capable of responding to C-ECHO requests
- *  (Verification SOP Class).
+ *  of the server.
+ *  The DcmSCP base class does not support any presentation contexts per default.
+ *  In particular the Verification SOP class which every SCP must support,
+ *  is not added automatically in order to give the user full control over the
+ *  supported list of presentation contexts. However, if this class should negotiate
+ *  Verification, call setEnableVerification(). In that case DcmSCP will also
+ *  respond to related C-ECHO requests. Note that this cannot be reverted.
  *  @warning This class is EXPERIMENTAL. Be careful to use it in production environment.
  */
 class DCMTK_DCMNET_EXPORT DcmSCP
@@ -159,6 +162,19 @@ public:
    *          be used to return after an association has been handled and ended.
    *          In that case, NET_EC_StopAfterAssociation is returned.</li>
    *          </ul>
+   *         Other error codes include
+   *          <ul>
+   *          <li>NET_EC_InvalidSCPAssociationProfile: Returned if the SCP's presentation
+   *          context information is invalid (e.g. no presentation contexts have
+   *          been added).
+   *          </li>
+   *          <li>NET_EC_InsufficientPortPrivileges: Returned if the SCP is not
+   *          allowed to open the specified TCP port for listening. The reason
+   *          may be that you try to open a port number below 1024 on a Unix-like
+   *          system as non-root user.
+   *          <li>EC_setuidFailed: Returned (on Unix-like systems) if the DcmSCP
+   *          was not able to drop root privileges.
+   *          </ul>
    */
   virtual OFCondition listen();
 
@@ -166,6 +182,21 @@ public:
   /*             Set methods for configuring SCP behavior          */
   /* ************************************************************* */
 
+  /** Enables negotiation of the Verification SOP Class. It adds the Verification
+   *  SOP Class to the list of supported abstract syntaxes for the given profile.
+   *  All uncompressed transfer syntaxes are supported. If Verification SOP
+   *  class is added here, DcmSCP will respond to related C-ECHO requests. Note
+   *  that this cannot be reverted.
+   *  The default behavior of DcmSCP is not to support any SOP Class at all.
+   *  @param profile [in] The profile Verification SOP Class should
+   *                 be added to. The default is to add it to the
+   *                 DcmSCP's internal standard profile called
+   *                 "DEFAULT".
+   *  @return EC_Normal if Verification SOP Class could be added,
+   *          error otherwise.
+   */
+  OFCondition setEnableVerification(const OFString& profile="DEFAULT");
+
   /** Add abstract syntax to presentation contexts the SCP is able to negotiate with SCUs.
    *  @param abstractSyntax [in] The UID of the abstract syntax (e.g.\ SOP class) to add
    *  @param xferSyntaxes   [in] List of transfer syntaxes (UIDs) that should be supported
@@ -288,7 +319,7 @@ public:
   /** Enables or disables looking up the host name from a connecting system.
    *  Note that this sets a GLOBAL flag in DCMTK, i.e. the behavior changes
    *  for all servers. This should be changed in the future.
-   *  @param mode [in] OFTrue, if hostname lookup should be enabled, OFFalse for disabling it.
+   *  @param mode [in] OFTrue, if host name lookup should be enabled, OFFalse for disabling it.
    */
   void setHostLookupEnabled(const OFBool mode);
 
@@ -375,7 +406,7 @@ public:
   OFBool getVerbosePCMode() const;
 
   /** Returns whether a connecting system's host name is looked up.
-   *  @return OFTrue, if hostname lookup is enabled, OFFalse otherwise
+   *  @return OFTrue, if host name lookup is enabled, OFFalse otherwise
    */
   OFBool getHostLookupEnabled() const;
 
@@ -443,7 +474,7 @@ public:
    */
   Uint32 getPeerMaxPDULength() const;
 
-  // DcmThreadSCP needs access to configuration (m_cfg), at least
+  /// DcmThreadSCP needs access to configuration (m_cfg), at least
   friend class DcmThreadSCP;
 
 protected:
@@ -475,9 +506,11 @@ protected:
   /* *********************************************************************** */
 
   /** Handle incoming command set and react accordingly, e.g.\ sending response via
-   *  DIMSE_sendXXXResponse(). The standard handler only knows how to handle an Echo request
-   *  by calling handleEchoRequest(). This function is most likely to be implemented by a
-   *  derived class implementing a specific SCP behavior.
+   *  DIMSE_sendXXXResponse(). The standard handler only knows how to handle
+   *  a C-ECHO request message (by calling handleEchoRequest()) if it is sent on a
+   *  presentation context configured for the Verification SOP Class.
+   *  This function is most likely to be implemented by a derived class
+   *  implementing a specific SCP behavior.
    *  @param incomingMsg The DIMSE message received
    *  @param presInfo Additional information on the Presentation Context used
    *  @return EC_Normal if the message could be handled, error if not. Especially
@@ -517,9 +550,8 @@ protected:
    */
   virtual OFBool checkCallingAETitleAccepted(const OFString& callingAE);
 
-  /** Overwrite this function if calling IP should undergo checking. Note
-   *  that this function may also return a hostname instead. If
-   *  OFTrue is returned, the IP is accepted and processing is continued.
+  /** Overwrite this function if calling IP / host name should undergo checking.
+   *  If OFTrue is returned, the host is accepted and processing is continued.
    *  In case of OFFalse, the SCP will refuse the incoming association with
    *  an error. The standard handler always returns OFTrue.
    *  @param hostOrIP The IP of the client to check.
