@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2010, OFFIS e.V.
+ *  Copyright (C) 1994-2018, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were partly developed by
@@ -105,6 +105,7 @@ DIMSE_findUser(
         T_ASC_Association *assoc,
         T_ASC_PresentationContextID presID,
         T_DIMSE_C_FindRQ *request, DcmDataset *requestIdentifiers,
+        int &responseCount,
         DIMSE_FindUserCallback callback, void *callbackData,
         T_DIMSE_BlockingMode blockMode, int timeout,
         T_DIMSE_C_FindRSP *response, DcmDataset **statusDetail)
@@ -142,7 +143,6 @@ DIMSE_findUser(
 {
     T_DIMSE_Message req, rsp;
     DIC_US msgId;
-    int responseCount = 0;
     DcmDataset *rspIds = NULL;
     DIC_US status = STATUS_Pending;
 
@@ -301,8 +301,8 @@ DIMSE_sendFindResponse(T_ASC_Association * assoc,
     rsp.CommandField = DIMSE_C_FIND_RSP;
     rsp.msg.CFindRSP = *response;
     rsp.msg.CFindRSP.MessageIDBeingRespondedTo = request->MessageID;
-    strcpy(rsp.msg.CFindRSP.AffectedSOPClassUID,
-            request->AffectedSOPClassUID);
+    OFStandard::strlcpy(rsp.msg.CFindRSP.AffectedSOPClassUID,
+            request->AffectedSOPClassUID, sizeof(rsp.msg.CFindRSP.AffectedSOPClassUID));
     rsp.msg.CFindRSP.opts = O_FIND_AFFECTEDSOPCLASSUID;
 
     /* specify if the response message will contain a search result or if it will not contain one, */
