@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2017, OFFIS e.V.
+ *  Copyright (C) 1994-2018, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were partly developed by
@@ -223,7 +223,8 @@ parseAssociate(unsigned char *buf, unsigned long pduLength,
             if (cond.good())
             {
                 buf += itemLength;
-                pduLength -= itemLength;
+                if (!OFStandard::safeSubtract(pduLength, itemLength, pduLength))
+                  return makeUnderflowError("Application Context item", pduLength, itemLength);
                 DCMNET_TRACE("Successfully parsed Application Context");
             }
             break;
@@ -235,7 +236,8 @@ parseAssociate(unsigned char *buf, unsigned long pduLength,
             cond = parsePresentationContext(type, context, buf, &itemLength, pduLength);
             if (cond.bad()) return cond;
             buf += itemLength;
-            pduLength -= itemLength;
+            if (!OFStandard::safeSubtract(pduLength, itemLength, pduLength))
+              return makeUnderflowError("Presentation Context item", pduLength, itemLength);
             LST_Enqueue(&assoc->presentationContextList, (LST_NODE*)context);
             DCMNET_TRACE("Successfully parsed Presentation Context");
             break;
@@ -246,11 +248,14 @@ parseAssociate(unsigned char *buf, unsigned long pduLength,
             if (cond.bad())
                 return cond;
             buf += itemLength;
-            pduLength -= itemLength;
+            if (!OFStandard::safeSubtract(pduLength, itemLength, pduLength))
+              return makeUnderflowError("User Information item", pduLength, itemLength);
             DCMNET_TRACE("Successfully parsed User Information");
             break;
         default:
             cond = parseDummy(buf, &itemLength, pduLength);
+            if (cond.bad())
+                return cond;
             buf += itemLength;
             if (!OFStandard::safeSubtract(pduLength, itemLength, pduLength))
               return makeUnderflowError("unknown item type", pduLength, itemLength);
@@ -396,7 +401,8 @@ parsePresentationContext(unsigned char type,
                     return cond;
 
                 buf += length;
-                presentationLength -= length;
+                if (!OFStandard::safeSubtract(presentationLength, length, presentationLength))
+                  return makeUnderflowError("Abstract Syntax", presentationLength, length);
                 DCMNET_TRACE("Successfully parsed Abstract Syntax");
                 break;
             case DUL_TYPETRANSFERSYNTAX:
@@ -406,11 +412,14 @@ parsePresentationContext(unsigned char type,
                 if (cond.bad()) return cond;
                 LST_Enqueue(&context->transferSyntaxList, (LST_NODE*)subItem);
                 buf += length;
-                presentationLength -= length;
+                if (!OFStandard::safeSubtract(presentationLength, length, presentationLength))
+                  return makeUnderflowError("Transfer Syntax", presentationLength, length);
                 DCMNET_TRACE("Successfully parsed Transfer Syntax");
                 break;
             default:
                 cond = parseDummy(buf, &length, presentationLength);
+                if (cond.bad())
+                    return cond;
                 buf += length;
                 if (!OFStandard::safeSubtract(presentationLength, length, presentationLength))
                   return makeUnderflowError("unknown presentation context type", presentationLength, length);
@@ -495,7 +504,8 @@ parseUserInfo(DUL_USERINFO * userInfo,
             if (cond.bad())
                 return cond;
             buf += length;
-            userLength -= (unsigned short) length;
+            if (!OFStandard::safeSubtract(userLength, OFstatic_cast(short unsigned int, length), userLength))
+              return makeLengthError("maximum length sub-item", userLength, length);
             DCMNET_TRACE("Successfully parsed Maximum PDU Length");
             break;
         case DUL_TYPEIMPLEMENTATIONCLASSUID:
@@ -504,11 +514,14 @@ parseUserInfo(DUL_USERINFO * userInfo,
             if (cond.bad())
                 return cond;
             buf += length;
-            userLength -= (unsigned short) length;
+            if (!OFStandard::safeSubtract(userLength, OFstatic_cast(short unsigned int, length), userLength))
+              return makeLengthError("Implementation Class UID sub-item", userLength, length);
             break;
 
         case DUL_TYPEASYNCOPERATIONS:
             cond = parseDummy(buf, &length, userLength);
+            if (cond.bad())
+                return cond;
             buf += length;
             if (!OFStandard::safeSubtract(userLength, OFstatic_cast(short unsigned int, length), userLength))
               return makeLengthError("asynchronous operation user item type", userLength, length);
@@ -520,14 +533,16 @@ parseUserInfo(DUL_USERINFO * userInfo,
             if (cond.bad()) return cond;
             LST_Enqueue(&userInfo->SCUSCPRoleList, (LST_NODE*)role);
             buf += length;
-            userLength -= (unsigned short) length;
+            if (!OFStandard::safeSubtract(userLength, OFstatic_cast(short unsigned int, length), userLength))
+              return makeLengthError("SCP/SCU Role Selection sub-item", userLength, length);
             break;
         case DUL_TYPEIMPLEMENTATIONVERSIONNAME:
             cond = parseSubItem(&userInfo->implementationVersionName,
                                 buf, &length, userLength);
             if (cond.bad()) return cond;
             buf += length;
-            userLength -= (unsigned short) length;
+            if (!OFStandard::safeSubtract(userLength, OFstatic_cast(short unsigned int, length), userLength))
+              return makeLengthError("Implementation Version Name structure", userLength, length);
             break;
 
         case DUL_TYPESOPCLASSEXTENDEDNEGOTIATION:
@@ -543,7 +558,8 @@ parseUserInfo(DUL_USERINFO * userInfo,
             }
             userInfo->extNegList->push_back(extNeg);
             buf += length;
-            userLength -= (unsigned short) length;
+            if (!OFStandard::safeSubtract(userLength, OFstatic_cast(short unsigned int, length), userLength))
+              return makeLengthError("SOP Class Extended Negotiation sub-item", userLength, length);
             break;
 
         case DUL_TYPENEGOTIATIONOFUSERIDENTITY_REQ:
@@ -561,16 +577,20 @@ parseUserInfo(DUL_USERINFO * userInfo,
           }
           userInfo->usrIdent = usrIdent;
           buf += length;
-          userLength -= (unsigned short) length;
+          if (!OFStandard::safeSubtract(userLength, OFstatic_cast(short unsigned int, length), userLength))
+            return makeLengthError("User Identity sub-item", userLength, length);
           break;
         default:
             // we hit an unknown user item that is not defined in the standard
             // or still unknown to DCMTK
             cond = parseDummy(buf, &length /* returns bytes "handled" by parseDummy */, userLength /* data available in bytes for user item */);
+            if (cond.bad())
+              return cond;
             // skip the bytes read
             buf += length;
             // subtract bytes of parsed data from available data bytes
-            if (!OFStandard::safeSubtract(userLength, OFstatic_cast(unsigned short, length), userLength))
+            if (OFstatic_cast(unsigned short, length) != length
+                || !OFStandard::safeSubtract(userLength, OFstatic_cast(unsigned short, length), userLength))
               return makeUnderflowError("unknown user item", userLength, length);
             break;
         }
