@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1999-2005, OFFIS
+ *  Copyright (C) 1999-2012, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module: dcmpstat
  *
@@ -22,13 +18,6 @@
  *  Purpose:
  *    classes: DVPSStoredPrint
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 16:04:03 $
- *  CVS/RCS Revision: $Revision: 1.38 $
- *  Status:           $State: Exp $
- *
- *  CVS/RCS Log at end of file
- *
  */
 
 
@@ -39,7 +28,6 @@
 
 #include "dcmtk/ofstd/ofstream.h"
 #include "dcmtk/ofstd/ofstring.h"
-#include "dcmtk/dcmdata/dctk.h"
 #include "dcmtk/dcmpstat/dvpstyp.h"         /* for enum types */
 #include "dcmtk/dcmpstat/dvpspll.h"         /* for class DVPSPresentationLUT_PList */
 #include "dcmtk/dcmpstat/dvpsibl.h"         /* for class DVPSImageBoxContent_PList */
@@ -53,7 +41,7 @@ class DVConfiguration;
 /** the representation of a Stored Print object
  */
 
-class DVPSStoredPrint
+class DCMTK_DCMPSTAT_EXPORT DVPSStoredPrint
 {
  public:
   /** constructor
@@ -887,13 +875,6 @@ class DVPSStoredPrint
    */
   void updatePresentationLUTList(DVPSPresentationLUT_PList& globalPresentationLUTList);
 
-  /** sets a new log stream
-   *  @param stream new log stream, NULL for default logstream
-   *  @param verbMode verbose mode flag
-   *  @param dbgMode debug mode flag
-   */
-  void setLog(OFConsole *stream, OFBool verbMode, OFBool dbgMode);
-
   /** checks whether the given Presentation LUT type could be used together
    *  with all image boxes in this film box on a Print SCP that requires a matching
    *  alignment between a Presentation LUT and the image pixel data.
@@ -988,7 +969,7 @@ class DVPSStoredPrint
   /// Module=General_Study, VR=TM, VM=1, Type 2
   DcmTime                  studyTime;
   /// Module=General_Study, VR=PN, VM=1, Type 2
-  DcmPersonName            referringPhysiciansName;
+  DcmPersonName            referringPhysicianName;
   /// Module=General_Study, VR=SH, VM=1, Type 2
   DcmShortString           studyID;
   /// Module=General_Study, VR=SH, VM=1, Type 2
@@ -1131,155 +1112,6 @@ class DVPSStoredPrint
   /// temporary buffer for getMaxDensity and getMinDensity
   OFString tempDensity;
 
-  /** output stream for error messages, never NULL
-   */
-  OFConsole *logstream;
-
-  /** flag indicating whether we're operating in verbose mode
-   */
-  OFBool verboseMode;
-
-  /** flag indicating whether we're operating in debug mode
-   */
-  OFBool debugMode;
-
 };
 
 #endif
-
-/*
- *  $Log: dvpssp.h,v $
- *  Revision 1.38  2005/12/08 16:04:03  meichel
- *  Changed include path schema for all DCMTK header files
- *
- *  Revision 1.37  2004/02/04 15:49:09  joergr
- *  Removed acknowledgements with e-mail addresses from CVS log. Removed leading
- *  underscore characters from preprocessor symbols (reserved symbols).
- *
- *  Revision 1.36  2002/04/16 14:02:03  joergr
- *  Added configurable support for C++ ANSI standard includes (e.g. streams).
- *
- *  Revision 1.35  2001/09/26 15:36:15  meichel
- *  Adapted dcmpstat to class OFCondition
- *
- *  Revision 1.34  2001/06/01 15:50:21  meichel
- *  Updated copyright header
- *
- *  Revision 1.33  2000/07/18 16:03:44  joergr
- *  Moved method convertODtoLum/PValue from class DVInterface to DVPSStoredPrint
- *  and corrected implementation.
- *  Changed behaviour of methods getMin/MaxDensityValue (return default value if
- *  attribute empty/absent).
- *
- *  Revision 1.32  2000/07/07 14:14:24  joergr
- *  Added support for LIN OD presentation LUT shape.
- *
- *  Revision 1.31  2000/07/05 12:33:29  joergr
- *  Corrected documentation of one method.
- *
- *  Revision 1.30  2000/07/04 15:58:03  joergr
- *  Added support for overriding the presentation LUT settings made for the
- *  image boxes.
- *
- *  Revision 1.29  2000/06/20 14:50:08  meichel
- *  Added monochrome1 printing mode.
- *
- *  Revision 1.28  2000/06/19 16:29:07  meichel
- *  Added options for session printing and LIN OD to print tools, fixed
- *    pixel aspect ratio related bug.
- *
- *  Revision 1.27  2000/06/14 11:28:15  joergr
- *  Added methods to access the attributes Polarity and Requested Image Size.
- *
- *  Revision 1.26  2000/06/08 10:44:29  meichel
- *  Implemented Referenced Presentation LUT Sequence on Basic Film Session level.
- *    Empty film boxes (pages) are not written to file anymore.
- *
- *  Revision 1.25  2000/06/07 14:23:09  joergr
- *  Added methods to access the image polarity attribute.
- *  Added missing transformations (polarity, GSDF, presentation LUT, aspect
- *  ratio) to print preview rendering.
- *
- *  Revision 1.24  2000/06/07 13:17:46  meichel
- *  added binary and textual log facilities to Print SCP.
- *
- *  Revision 1.23  2000/06/02 16:00:51  meichel
- *  Adapted all dcmpstat classes to use OFConsole for log and error output
- *
- *  Revision 1.22  2000/05/31 12:56:39  meichel
- *  Added initial Print SCP support
- *
- *  Revision 1.21  2000/05/31 07:54:24  joergr
- *  Added support for Stored Print attributes Originator and Destination
- *  application entity title.
- *
- *  Revision 1.20  2000/05/30 13:42:09  joergr
- *  Added methods to set, get and store the printer name in the stored print
- *  object (PrinterCharacteristicsSequence).
- *
- *  Revision 1.19  2000/03/08 16:28:56  meichel
- *  Updated copyright header.
- *
- *  Revision 1.18  2000/03/03 14:13:55  meichel
- *  Implemented library support for redirecting error messages into memory
- *    instead of printing them to stdout/stderr for GUI applications.
- *
- *  Revision 1.17  2000/02/29 12:16:16  meichel
- *  Fixed bug in dcmpstat library that caused Monochrome1 images
- *    to be printed inverse if a Presentation LUT was applied.
- *
- *  Revision 1.16  1999/10/19 14:46:04  meichel
- *  added support for the Basic Annotation Box SOP Class
- *    as well as access methods for Max Density and Min Density.
- *
- *  Revision 1.15  1999/10/13 14:11:12  meichel
- *  Fixed bug in routine that renders P-LUTs into a print bitmap
- *    before sending an image to the printer
- *
- *  Revision 1.14  1999/10/07 17:21:50  meichel
- *  Reworked management of Presentation LUTs in order to create tighter
- *    coupling between Softcopy and Print.
- *
- *  Revision 1.13  1999/09/24 15:24:30  meichel
- *  Added support for CP 173 (Presentation LUT clarifications)
- *
- *  Revision 1.12  1999/09/17 14:33:59  meichel
- *  Completed print spool functionality including Supplement 22 support
- *
- *  Revision 1.11  1999/09/15 17:43:29  meichel
- *  Implemented print job dispatcher code for dcmpstat, adapted dcmprtsv
- *    and dcmpsprt applications.
- *
- *  Revision 1.10  1999/09/13 15:19:10  meichel
- *  Added implementations for a number of further print API methods.
- *
- *  Revision 1.9  1999/09/10 12:46:47  meichel
- *  Added implementations for a number of print API methods.
- *
- *  Revision 1.8  1999/09/09 14:57:33  thiel
- *  Added methods for print spooler
- *
- *  Revision 1.7  1999/09/09 12:20:47  meichel
- *  Added print API method declarations and implementations (empty for now).
- *
- *  Revision 1.6  1999/09/08 16:46:44  meichel
- *  Added print API method declarations
- *
- *  Revision 1.5  1999/09/01 16:14:41  meichel
- *  Added support for requested image size to print routines
- *
- *  Revision 1.4  1999/08/31 14:09:12  meichel
- *  Added get/set methods for stored print attributes
- *
- *  Revision 1.3  1999/08/27 15:57:57  meichel
- *  Added methods for saving hardcopy images and stored print objects
- *    either in file or in the local database.
- *
- *  Revision 1.2  1999/08/26 09:31:00  thiel
- *  Add extensions for the usage of the StoredPrint
- *
- *  Revision 1.1  1999/07/30 13:34:50  meichel
- *  Added new classes managing Stored Print objects
- *
- *
- */
