@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1998-2017, OFFIS e.V.
+ *  Copyright (C) 1998-2018, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -23,6 +23,7 @@
 #include "dcmtk/config/osconfig.h"    /* make sure OS specific configuration is included first */
 
 #include "dcmtk/ofstd/ofstring.h"
+#include "dcmtk/ofstd/ofstd.h"
 #include "dcmtk/dcmpstat/dvpsdef.h"
 #include "dcmtk/dcmpstat/dvpspr.h"
 
@@ -236,10 +237,10 @@ OFCondition DVPSPrintMessageHandler::createRQ(
   // construct N-CREATE-RQ
   request.CommandField = DIMSE_N_CREATE_RQ;
   request.msg.NCreateRQ.MessageID = assoc->nextMsgID++;
-  strcpy(request.msg.NCreateRQ.AffectedSOPClassUID, sopclassUID);
+  OFStandard::strlcpy(request.msg.NCreateRQ.AffectedSOPClassUID, sopclassUID, sizeof(request.msg.NCreateRQ.AffectedSOPClassUID));
   if (sopinstanceUID.size() > 0)
   {
-    strcpy(request.msg.NCreateRQ.AffectedSOPInstanceUID, sopinstanceUID.c_str());
+    OFStandard::strlcpy(request.msg.NCreateRQ.AffectedSOPInstanceUID, sopinstanceUID.c_str(), sizeof(request.msg.NCreateRQ.AffectedSOPInstanceUID));
     request.msg.NCreateRQ.opts = O_NCREATE_AFFECTEDSOPINSTANCEUID;
   } else {
     request.msg.NCreateRQ.AffectedSOPInstanceUID[0] = 0;
@@ -289,8 +290,8 @@ OFCondition DVPSPrintMessageHandler::setRQ(
   // construct N-SET-RQ
   request.CommandField = DIMSE_N_SET_RQ;
   request.msg.NSetRQ.MessageID = assoc->nextMsgID++;
-  strcpy(request.msg.NSetRQ.RequestedSOPClassUID, sopclassUID);
-  strcpy(request.msg.NSetRQ.RequestedSOPInstanceUID, sopinstanceUID);
+  OFStandard::strlcpy(request.msg.NSetRQ.RequestedSOPClassUID, sopclassUID, sizeof(request.msg.NSetRQ.RequestedSOPClassUID));
+  OFStandard::strlcpy(request.msg.NSetRQ.RequestedSOPInstanceUID, sopinstanceUID, sizeof(request.msg.NSetRQ.RequestedSOPInstanceUID));
    
   OFCondition cond = sendNRequest(presCtx, request, modificationList, response, statusDetail, attributeListOut);
   if (cond.good()) status = response.msg.NSetRSP.DimseStatus;
@@ -328,8 +329,8 @@ OFCondition DVPSPrintMessageHandler::getRQ(
   // construct N-GET-RQ
   request.CommandField = DIMSE_N_GET_RQ;
   request.msg.NGetRQ.MessageID = assoc->nextMsgID++;
-  strcpy(request.msg.NGetRQ.RequestedSOPClassUID, sopclassUID);
-  strcpy(request.msg.NGetRQ.RequestedSOPInstanceUID, sopinstanceUID);
+  OFStandard::strlcpy(request.msg.NGetRQ.RequestedSOPClassUID, sopclassUID, sizeof(request.msg.NGetRQ.RequestedSOPClassUID));
+  OFStandard::strlcpy(request.msg.NGetRQ.RequestedSOPInstanceUID, sopinstanceUID, sizeof(request.msg.NGetRQ.RequestedSOPInstanceUID));
   request.msg.NGetRQ.ListCount = 0;
   if (attributeIdentifierList) request.msg.NGetRQ.ListCount = (int)numShorts;
   request.msg.NGetRQ.AttributeIdentifierList = (DIC_US *)attributeIdentifierList;
@@ -371,8 +372,8 @@ OFCondition DVPSPrintMessageHandler::actionRQ(
   // construct N-ACTION-RQ
   request.CommandField = DIMSE_N_ACTION_RQ;
   request.msg.NActionRQ.MessageID = assoc->nextMsgID++;
-  strcpy(request.msg.NActionRQ.RequestedSOPClassUID, sopclassUID);
-  strcpy(request.msg.NActionRQ.RequestedSOPInstanceUID, sopinstanceUID);
+  OFStandard::strlcpy(request.msg.NActionRQ.RequestedSOPClassUID, sopclassUID, sizeof(request.msg.NActionRQ.RequestedSOPClassUID));
+  OFStandard::strlcpy(request.msg.NActionRQ.RequestedSOPInstanceUID, sopinstanceUID, sizeof(request.msg.NActionRQ.RequestedSOPInstanceUID));
   request.msg.NActionRQ.ActionTypeID = (DIC_US)actionTypeID;
    
   OFCondition cond = sendNRequest(presCtx, request, actionInformation, response, statusDetail, actionReply);
@@ -409,8 +410,8 @@ OFCondition DVPSPrintMessageHandler::deleteRQ(
   // construct N-DELETE-RQ
   request.CommandField = DIMSE_N_DELETE_RQ;
   request.msg.NDeleteRQ.MessageID = assoc->nextMsgID++;
-  strcpy(request.msg.NDeleteRQ.RequestedSOPClassUID, sopclassUID);
-  strcpy(request.msg.NDeleteRQ.RequestedSOPInstanceUID, sopinstanceUID);
+  OFStandard::strlcpy(request.msg.NDeleteRQ.RequestedSOPClassUID, sopclassUID, sizeof(request.msg.NDeleteRQ.RequestedSOPClassUID));
+  OFStandard::strlcpy(request.msg.NDeleteRQ.RequestedSOPInstanceUID, sopinstanceUID, sizeof(request.msg.NDeleteRQ.RequestedSOPInstanceUID));
    
   OFCondition cond = sendNRequest(presCtx, request, NULL, response, statusDetail, attributeListOut);
   if (cond.good()) status = response.msg.NDeleteRSP.DimseStatus;
