@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2015-2018, Open Connections GmbH
+ *  Copyright (C) 2015-2019, Open Connections GmbH
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation are maintained by
@@ -256,9 +256,23 @@ OFCondition DcmSegmentation::read(DcmItem &dataset)
 }
 
 
+void DcmSegmentation::setCheckFGOnWrite(const OFBool doCheck)
+{
+  m_FGInterface.setCheckOnWrite(doCheck);
+}
+
+
+OFBool DcmSegmentation::getCheckFGOnWrite()
+{
+  return m_FGInterface.getCheckOnWrite();
+}
+
+
 OFCondition DcmSegmentation::write(DcmItem &dataset)
 {
-  if (!check())
+  // FGInterface::write() will know whether it has to check FG structure
+  // so we do not need to check FG structure here (OFFalse).
+  if (!check(OFFalse))
   {
     return IOD_EC_InvalidObject;
   }
@@ -380,7 +394,16 @@ OFCondition DcmSegmentation::addFrame(Uint8* pixData)
       if (frame)
       {
         frame->length = rows*cols;
-        frame->pixData = pixData;
+        frame->pixData = new Uint8[frame->length];
+        if (frame->pixData)
+        {
+          memcpy(frame->pixData, pixData, frame->length);
+        }
+        else
+        {
+          delete frame;
+          result = EC_MemoryExhausted;
+        }
       }
       else
         result = EC_MemoryExhausted;
@@ -395,7 +418,6 @@ OFCondition DcmSegmentation::addFrame(Uint8* pixData)
     DCMSEG_ERROR("Cannot add frame since rows and/or columns are unknown");
     result = IOD_EC_CannotInsertFrame;
   }
-
   return result;
 }
 
@@ -1229,7 +1251,7 @@ IODImagePixelModule<Uint8>& DcmSegmentation::getImagePixel()
 }
 
 
-OFBool DcmSegmentation::check()
+OFBool DcmSegmentation::check(const OFBool checkFGStructure)
 {
   if (m_Frames.size() == 0)
   {
@@ -1247,9 +1269,10 @@ OFBool DcmSegmentation::check()
     return OFFalse;
   }
 
-  if (!m_FGInterface.check())
+  if (checkFGStructure)
   {
-    return OFFalse;
+     if (!m_FGInterface.check())
+       return OFFalse;
   }
 
   // Check rules around Frame of Reference
@@ -1283,7 +1306,7 @@ OFBool DcmSegmentation::check()
     // Check that each of above FGs is present. We do not check this for
     // all frames since if it exists for one frame it must exist for all others.
     // This is a general rule and applies for all FGs, so it is not checked here.
-    FGBase* group = m_FGInterface.get(OFstatic_cast(Uint32, 0), DcmFGTypes::EFG_PIXELMEASURES);
+    group = m_FGInterface.get(OFstatic_cast(Uint32, 0), DcmFGTypes::EFG_PIXELMEASURES);
     if (!group)
     {
       DCMSEG_ERROR("Frame of Reference UID is present but Pixel Measures FG is missing");
@@ -1360,7 +1383,7 @@ OFCondition DcmSegmentation::extractFrames(Uint8* pixData,
   size_t overlapBits = (8 - (bitsPerFrame % 8)) % 8;
   // Add an extra byte if we we fill a partial byte in the end
   if (overlapBits != 0) frameLengthBytes++;
-  // Points to current reading position within pixeldata
+  // Points to current reading position within pixData
   Uint8* readPos = pixData;
   // Loop over each frame and copy it to Frame structures
   for (size_t f = 0; f < numFrames; f++)
