@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1998-2010, OFFIS e.V.
+ *  Copyright (C) 1998-2018, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -18,13 +18,6 @@
  *  Purpose:
  *    classes: SiBaseRSAProfile
  *
- *  Last Update:      $Author: joergr $
- *  Update Date:      $Date: 2010-10-14 13:17:24 $
- *  CVS/RCS Revision: $Revision: 1.4 $
- *  Status:           $State: Exp $
- *
- *  CVS/RCS Log at end of file
- *
  */
 
 #ifndef SIBRSAPR_H
@@ -36,8 +29,10 @@
 #ifdef WITH_OPENSSL
 
 /** Base RSA Digital Signature Profile
+ *  @remark This class is only available if DCMTK is compiled with
+ *  OpenSSL support enabled.
  */
-class SiBaseRSAProfile: public SiSecurityProfile
+class DCMTK_DCMSIGN_EXPORT SiBaseRSAProfile: public SiSecurityProfile
 {
 public:
 
@@ -83,22 +78,3 @@ public:
 
 #endif
 #endif
-
-/*
- *  $Log: sibrsapr.h,v $
- *  Revision 1.4  2010-10-14 13:17:24  joergr
- *  Updated copyright header. Added reference to COPYRIGHT file.
- *
- *  Revision 1.3  2005-12-08 16:04:32  meichel
- *  Changed include path schema for all DCMTK header files
- *
- *  Revision 1.2  2003/06/04 14:21:03  meichel
- *  Simplified include structure to avoid preprocessor limitation
- *    (max 32 #if levels) on MSVC5 with STL.
- *
- *  Revision 1.1  2001/11/16 15:50:49  meichel
- *  Adapted digital signature code to final text of supplement 41.
- *
- *
- */
-
