@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1998-2010, OFFIS e.V.
+ *  Copyright (C) 1998-2018, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -18,13 +18,6 @@
  *  Purpose:
  *    classes: SiMD5
  *
- *  Last Update:      $Author: joergr $
- *  Update Date:      $Date: 2010-10-14 13:17:25 $
- *  CVS/RCS Revision: $Revision: 1.6 $
- *  Status:           $State: Exp $
- *
- *  CVS/RCS Log at end of file
- *
  */
 
 #ifndef SIMD5_H
@@ -41,28 +34,30 @@ typedef struct MD5state_st MD5_CTX;
 
 /**
  * a class implementing the hash function MD5
+ * @remark this class is only available if DCMTK is compiled with
+ * OpenSSL support enabled.
  */
-class SiMD5 : public SiMAC 
-{    
+class DCMTK_DCMSIGN_EXPORT SiMD5 : public SiMAC
+{
 public:
   /// default constructor
   SiMD5();
 
   /// destructor
   virtual ~SiMD5();
-  
+
   /** initializes the MAC algorithm.
    *  @return status code
    */
   virtual OFCondition initialize();
-  
+
   /** feeds data into the MAC algorithm
    *  @param data pointer to raw data to be fed into the MAC, must not be NULL
    *  @param length number of bytes in raw data array
    *  @return status code
    */
   virtual OFCondition digest(const unsigned char *data, unsigned long length);
-  
+
   /** finalizes the MAC and writes it to the given output array,
    *  which must be at least getSize() bytes large.
    *  After a call to finalize, the MAC algorithm must be initialized
@@ -80,7 +75,7 @@ public:
   /** returns the type of MAC algorithm computed by this object
    *  @return type of MAC algorithm
    */
-  virtual E_MACType macType() const;    
+  virtual E_MACType macType() const;
 
   /** returns the DICOM identifier for this MAC algorithm
    *  @return DICOM defined term for algorithm
@@ -96,33 +91,8 @@ private:
   SiMD5& operator=(SiMD5& arg);
 
   /// OpenSSL MD5 context
-  MD5_CTX *ctx;    
+  MD5_CTX *ctx;
 };
 
 #endif
 #endif
-
-/*
- *  $Log: simd5.h,v $
- *  Revision 1.6  2010-10-14 13:17:25  joergr
- *  Updated copyright header. Added reference to COPYRIGHT file.
- *
- *  Revision 1.5  2005-12-08 16:04:39  meichel
- *  Changed include path schema for all DCMTK header files
- *
- *  Revision 1.4  2003/06/04 14:21:03  meichel
- *  Simplified include structure to avoid preprocessor limitation
- *    (max 32 #if levels) on MSVC5 with STL.
- *
- *  Revision 1.3  2001/09/26 14:30:20  meichel
- *  Adapted dcmsign to class OFCondition
- *
- *  Revision 1.2  2001/06/01 15:50:49  meichel
- *  Updated copyright header
- *
- *  Revision 1.1  2000/11/07 16:48:56  meichel
- *  Initial release of dcmsign module for DICOM Digital Signatures
- *
- *
- */
-
