@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2017, OFFIS e.V.
+ *  Copyright (C) 2000-2019, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -407,8 +407,10 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *  The DICOM standard states: "Such referenced Instances may include equivalent documents or
      *  renderings of this document. [...] Required if the identity of a CDA Document equivalent
      *  to the current SOP Instance is known at the time of creation of this SOP instance. May be
-     *  present otherwise."  Note: An equivalent rendering of the document might be provided as an
-     *  "Encapsulated PDF" DICOM object.
+     *  present otherwise."  The Purpose of Reference Code should be taken from Defined Context
+     *  Group 7006 (SR Document Purposes of Reference).
+     *  Note: An equivalent rendering of the document might be provided as an "Encapsulated PDF"
+     *  DICOM object.
      *  @note Not applicable to Key Object Selection Documents.
      ** @return reference to list object
      */
@@ -577,7 +579,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     virtual OFCondition getDeviceSerialNumber(OFString &value,
                                               const signed long pos = 0) const;
 
-    /** get software version(s). Please note that only the first component is returned.
+    /** get software version(s)
      ** @param  value  reference to variable in which the value should be stored
      *  @param  pos    index of the value to get (0..vm-1), -1 for all components
      ** @return status, EC_Normal if successful, an error code otherwise
@@ -585,6 +587,30 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     virtual OFCondition getSoftwareVersions(OFString &value,
                                             const signed long pos = 0) const;
 
+    /** get synchronization frame of reference UID
+     ** @param  value  reference to variable in which the value should be stored
+     *  @param  pos    index of the value to get (0..vm-1), -1 for all components
+     ** @return status, EC_Normal if successful, an error code otherwise
+     */
+    virtual OFCondition getSynchronizationFrameOfReferenceUID(OFString &value,
+                                                              const signed long pos = 0) const;
+
+    /** get synchronization trigger
+     ** @param  value  reference to variable in which the value should be stored
+     *  @param  pos    index of the value to get (0..vm-1), -1 for all components
+     ** @return status, EC_Normal if successful, an error code otherwise
+     */
+    virtual OFCondition getSynchronizationTrigger(OFString &value,
+                                                  const signed long pos = 0) const;
+
+    /** get acquisition time synchronized
+     ** @param  value  reference to variable in which the value should be stored
+     *  @param  pos    index of the value to get (0..vm-1), -1 for all components
+     ** @return status, EC_Normal if successful, an error code otherwise
+     */
+    virtual OFCondition getAcquisitionTimeSynchronized(OFString &value,
+                                                       const signed long pos = 0) const;
+
     /** get study date
      ** @param  value  reference to variable in which the value should be stored
      *  @param  pos    index of the value to get (0..vm-1), -1 for all components
@@ -665,6 +691,14 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     virtual OFCondition getPatientID(OFString &value,
                                      const signed long pos = 0) const;
 
+    /** get issuer of patient ID
+     ** @param  value  reference to variable in which the value should be stored
+     *  @param  pos    index of the value to get (0..vm-1), -1 for all components
+     ** @return status, EC_Normal if successful, an error code otherwise
+     */
+    virtual OFCondition getIssuerOfPatientID(OFString &value,
+                                             const signed long pos = 0) const;
+
     /** get series number
      ** @param  value  reference to variable in which the value should be stored
      *  @param  pos    index of the value to get (0..vm-1), -1 for all components
@@ -813,6 +847,29 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     virtual OFCondition setSoftwareVersions(const OFString &value,
                                             const OFBool check = OFTrue);
 
+    /** set synchronization frame of reference UID
+     ** @param  value  value to be set (single value only) or "" for no value
+     *  @param  check  check 'value' for conformance with VR (UI) and VM (1) if enabled
+     ** @return status, EC_Normal if successful, an error code otherwise
+     */
+    virtual OFCondition setSynchronizationFrameOfReferenceUID(const OFString &value,
+                                                              const OFBool check = OFTrue);
+    /** set synchronization trigger
+     ** @param  value  value to be set (single value only) or "" for no value
+     *  @param  check  check 'value' for conformance with VR (CS) and VM (1) if enabled
+     ** @return status, EC_Normal if successful, an error code otherwise
+     */
+    virtual OFCondition setSynchronizationTrigger(const OFString &value,
+                                                  const OFBool check = OFTrue);
+
+    /** set acquisition time synchronized
+     ** @param  value  value to be set (single value only) or "" for no value
+     *  @param  check  check 'value' for conformance with VR (CS) and VM (1) if enabled
+     ** @return status, EC_Normal if successful, an error code otherwise
+     */
+    virtual OFCondition setAcquisitionTimeSynchronized(const OFString &value,
+                                                       const OFBool check = OFTrue);
+
     /** set content date
      ** @param  value  value to be set (single value only).  If an empty string is passed,
      *                 the current date is set when displaying or writing the document since
@@ -881,6 +938,14 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     virtual OFCondition setPatientID(const OFString &value,
                                      const OFBool check = OFTrue);
 
+    /** set issuer of patient ID
+     ** @param  value  value to be set (single value only) or "" for no value
+     *  @param  check  check 'value' for conformance with VR (LO) and VM (1) if enabled
+     ** @return status, EC_Normal if successful, an error code otherwise
+     */
+    virtual OFCondition setIssuerOfPatientID(const OFString &value,
+                                             const OFBool check = OFTrue);
+
     /** set series number
      ** @param  value  value to be set (single value only).  If an empty string is passed,
      *                 the value "1" is set when displaying or writing the document since
@@ -1289,6 +1354,8 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     DcmPersonName       PatientName;
     /// Patient ID: (LO, 1, 2)
     DcmLongString       PatientID;
+    /// Issuer of Patient ID: (LO, 1, 3)
+    DcmLongString       IssuerOfPatientID;
     /// Patient's Birth Date: (DA, 1, 2)
     DcmDate             PatientBirthDate;
     /// Patient's Sex: (CS, 1, 2)
@@ -1316,9 +1383,14 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     // Software Version(s): (LO, 1-n, 1)
     // - see 'General Equipment Module'
 
-    // --- Synchronization Module (C/U - for some IODs) ---
+    // --- Synchronization Module (M/C/U - for some IODs) ---
 
-    // tbd: conditional/optional module not yet supported
+    /// Synchronization Frame of Reference UID: (UI, 1, 1)
+    DcmUniqueIdentifier SynchronizationFrameOfReferenceUID;
+    /// Synchronization Trigger: (CS, 1, 1)
+    DcmCodeString       SynchronizationTrigger;
+    /// Acquisition Time Synchronized: (CS, 1, 1)
+    DcmCodeString       AcquisitionTimeSynchronized;
 
     // --- SR Document Series / Key Object Document Series Module (M) ---
 
