@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2015, OFFIS e.V.
+ *  Copyright (C) 2000-2016, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -28,14 +28,16 @@
 
 #include "dcmtk/dcmsr/dsrcodvl.h"
 
-#include "dcmtk/ofstd/ofstring.h"
+#include "dcmtk/dcmdata/dcvrfd.h"
+#include "dcmtk/dcmdata/dcvrsl.h"
+#include "dcmtk/dcmdata/dcvrul.h"
 
 
 /*---------------------*
  *  class declaration  *
  *---------------------*/
 
-/** Class for numeric measurement values
+/** Class for numeric values and measurements
  */
 class DCMTK_DCMSR_EXPORT DSRNumericMeasurementValue
 {
@@ -49,25 +51,36 @@ class DCMTK_DCMSR_EXPORT DSRNumericMeasurementValue
     DSRNumericMeasurementValue();
 
     /** constructor
-     ** @param  numericValue     numeric measurement value (VR=DS, mandatory)
+     ** @param  numericValue     numeric value (VR=DS, mandatory)
      *  @param  measurementUnit  code representing the units of measurement (mandatory)
      *  @param  check            if enabled, check 'numericValue' and 'measurementUnit' for
-     *                           validity before setting them.  See checkXXX() methods for
-     *                           details.  Empty values are never accepted.
+     *                           validity before setting them.  See corresponding setValue()
+     *                           method for details.
      */
     DSRNumericMeasurementValue(const OFString &numericValue,
                                const DSRCodedEntryValue &measurementUnit,
                                const OFBool check = OFTrue);
 
     /** constructor
-     ** @param  numericValue     numeric measurement value (VR=DS, mandatory)
+     ** @param  valueQualifier  code representing the numeric value qualifier.  Used to
+     *                          specify the reason for the absence of the measured value
+     *                          sequence, i.e. why the numeric value and measurement unit
+     *                          are empty.
+     *  @param  check           if enabled, check value for validity before setting it.
+     *                          See corresponding setValue() method for details.
+     */
+    DSRNumericMeasurementValue(const DSRCodedEntryValue &valueQualifier,
+                               const OFBool check = OFTrue);
+
+    /** constructor
+     ** @param  numericValue     numeric value (VR=DS, mandatory)
      *  @param  measurementUnit  code representing the units of measurement (mandatory)
      *  @param  valueQualifier   code representing the numeric value qualifier (optional).
      *                           Can also be used to specify the reason for the absence of
-     *                           the measured value sequence.
+     *                           the measured value sequence (where 'numericValue' and
+     *                           'measurementUnit' are stored).
      *  @param  check            if enabled, check values for validity before setting them.
-     *                           See checkXXX() for details.  Empty values are only accepted
-     *                           for non-mandatory attributes.
+     *                           See corresponding setValue() method for details.
      */
     DSRNumericMeasurementValue(const OFString &numericValue,
                                const DSRCodedEntryValue &measurementUnit,
@@ -89,15 +102,35 @@ class DCMTK_DCMSR_EXPORT DSRNumericMeasurementValue
      */
     DSRNumericMeasurementValue &operator=(const DSRNumericMeasurementValue &numericMeasurement);
 
+    /** comparison operator "equal".
+     *  Two numeric measurement values are equal if the numeric value, the measurement unit
+     *  and the value qualifier are equal.  Other (additional) information is not used.
+     ** @param  numericMeasurement  numeric measurement value that should be compared to the
+     *                              current one
+     ** @return OFTrue if both numeric measurement values are equal, OFFalse otherwise
+     */
+    OFBool operator==(const DSRNumericMeasurementValue &numericMeasurement) const;
+
+    /** comparison operator "not equal".
+     *  Two numeric measurement values are not equal if either the numeric value or the
+     *  measurement unit or the value qualifier are not equal.  Other (additional) information
+     *  is not used for comparison.
+     ** @param  numericMeasurement  numeric measurement value that should be compared to the
+     *                              current one
+     ** @return OFTrue if both numeric measurement values are not equal, OFFalse otherwise
+     */
+    OFBool operator!=(const DSRNumericMeasurementValue &numericMeasurement) const;
+
     /** clear all internal variables.
      *  Use this method to create an empty numeric measurement value.
      */
     virtual void clear();
 
     /** check whether the current numeric measurement value is valid.
-     *  The value is valid if isEmpty() is true or all three values (numeric value, measurement
-     *  unit and value qualifier) do contain valid values (see checkXXX() methods).  The
-     *  possibly available additional representations of the numeric value are never checked.
+     *  The value is valid if isEmpty() is true or both the numeric value and the measurement
+     *  unit contain a valid value, and the value qualifier is valid (see checkXXX() methods).
+     *  The possibly available additional representations of the numeric value are never
+     *  checked.
      ** @return OFTrue if value is valid, OFFalse otherwise
      */
     virtual OFBool isValid() const;
@@ -110,11 +143,21 @@ class DCMTK_DCMSR_EXPORT DSRNumericMeasurementValue
      */
     virtual OFBool isEmpty() const;
 
+    /** check whether the current numeric measurement value is complete, i.e.\ whether the
+     *  numeric value is non-empty and the measurement unit is complete, or whether the
+     *  value qualifier is complete.  This is just a basic check that might be useful for
+     *  "validating" input data.  See isValid() for a more sophisticated way of checking
+     *  the current numeric measurement value.
+     ** @return OFTrue if value is complete, OFFalse otherwise
+     */
+    virtual OFBool isComplete() const;
+
     /** print numeric measurement value.
      *  The output of a typical numeric measurement value looks like this:
-     *  "3.5" (cm,UCUM[1.4],"centimeter").  If the value is empty the text "empty" is printed
-     *  instead.  The numeric value qualifier as well as the possibly available additional
-     *  floating point and rational representations of the numeric value are never printed.
+     *  "3.5" (cm,UCUM[1.4],"centimeter").  If the value is empty, the text "empty" is printed
+     *  instead, followed by the numeric value qualifier (if present).  The possibly available
+     *  additional floating point and rational representations of the numeric value are never
+     *  printed.
      ** @param  stream  output stream to which the numeric measurement value should be printed
      *  @param  flags   flag used to customize the output (not used)
      ** @return status, EC_Normal if successful, an error code otherwise
@@ -255,10 +298,11 @@ class DCMTK_DCMSR_EXPORT DSRNumericMeasurementValue
                          const OFBool check = OFTrue);
 
     /** set numeric value and measurement unit.
-     *  Before setting the values, they are usually checked.  If the value pair is invalid,
-     *  the current value pair is not replaced and remains unchanged.  If the value pair is
-     *  replaced, the optional floating point and rational representations are cleared, i.e.
-     *  they have to be set manually if needed.
+     *  Before setting the values, they are usually checked.  Please note that both values
+     *  (i.e. 'numericValue' and 'measurementUnit') either have to be empty or non-empty.
+     *  If the value pair is invalid, the current value pair is not replaced and remains
+     *  unchanged.  If the value pair is replaced, the optional floating point and rational
+     *  representations are cleared, i.e. they have to be set manually if needed.
      ** @param  numericValue     numeric value to be set (VR=DS, mandatory)
      *  @param  measurementUnit  measurement unit to be set (mandatory)
      *  @param  check            if enabled, check values for validity before setting them.
@@ -269,20 +313,34 @@ class DCMTK_DCMSR_EXPORT DSRNumericMeasurementValue
                          const DSRCodedEntryValue &measurementUnit,
                          const OFBool check = OFTrue);
 
+    /** set empty numeric value and measurement unit with a numeric value qualifier.
+     *  Before setting the value, it is usually checked.  If the value is invalid, the
+     *  current numeric measurement value is not replaced and remains unchanged.
+     ** @param  valueQualifier  numeric value qualifier to be set.  Used to specify the
+     *                          reason for the absence of the measured value sequence,
+     *                          i.e. why the numeric value and measurement unit are empty.
+     *  @param  check           if enabled, check value for validity before setting it.
+     *                          See checkNumericValueQualifier() method for details.
+     ** @return status, EC_Normal if successful, an error code otherwise
+     */
+    OFCondition setValue(const DSRCodedEntryValue &valueQualifier,
+                         const OFBool check = OFTrue);
+
     /** set numeric value, measurement unit and numeric value qualifier.
-     *  Before setting the values, they are usually checked.  If one of the three values is
-     *  invalid, the current numeric measurement value is not replaced and remains unchanged.
-     *  If the values are replaced, the optional floating point and rational representations
-     *  are cleared, i.e. they have to be set manually if needed.
+     *  Before setting the values, they are usually checked.  Please note that both
+     *  'numericValue' and 'measurementUnit' either have to be empty or non-empty.
+     *  If one of the three values is invalid, the current numeric measurement value is not
+     *  replaced and remains unchanged.  If the values are replaced, the optional floating
+     *  point and rational representations are cleared, i.e. they have to be set manually if
+     *  needed.
      ** @param  numericValue     numeric value to be set (VR=DS, mandatory)
      *  @param  measurementUnit  measurement unit to be set (mandatory)
      *  @param  valueQualifier   numeric value qualifier to be set (optional).  Can also be
      *                           used to specify the reason for the absence of the measured
-     *                           value sequence.  Use an empty code to remove the current
-     *                           value.
+     *                           value sequence (where 'numericValue' and 'measurementUnit'
+     *                           are stored).  Use an empty code to remove the current value.
      *  @param  check            if enabled, check values for validity before setting them.
-     *                           See checkXXX() methods for details.  Empty values are only
-     *                           accepted for non-mandatory attributes.
+     *                           See checkXXX() methods for details.
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     OFCondition setValue(const OFString &numericValue,
@@ -298,7 +356,7 @@ class DCMTK_DCMSR_EXPORT DSRNumericMeasurementValue
      ** @param  numericValue  numeric value to be set (VR=DS, mandatory)
      *  @param  check         if enabled, check value for validity before setting it.
      *                        See checkNumericValue() method for details.  An empty value is
-     *                        never accepted.
+     *                        never accepted, use the clear() method instead.
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     OFCondition setNumericValue(const OFString &numericValue,
@@ -345,7 +403,7 @@ class DCMTK_DCMSR_EXPORT DSRNumericMeasurementValue
      ** @param  measurementUnit  measurement unit to be set (mandatory)
      *  @param  check            if enabled, check value for validity before setting it.
      *                           See checkMeasurementUnit() method for details.  An empty
-     *                           value is never accepted.
+     *                           value is never accepted, use the clear() method instead.
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     OFCondition setMeasurementUnit(const DSRCodedEntryValue &measurementUnit,
@@ -436,7 +494,7 @@ class DCMTK_DCMSR_EXPORT DSRNumericMeasurementValue
      ** @param  numericValue  numeric value to be checked
      ** @return status, EC_Normal if numeric value is valid, an error code otherwise
      */
-    OFCondition checkNumericValue(const OFString &numericValue) const;
+    virtual OFCondition checkNumericValue(const OFString &numericValue) const;
 
     /** check the specified measurement unit for validity.
      *  Internally, the methods DSRCodedEntryValue::isEmpty() and
@@ -445,16 +503,17 @@ class DCMTK_DCMSR_EXPORT DSRNumericMeasurementValue
      ** @param  measurementUnit  measurement unit to be checked
      ** @return status, EC_Normal if measurement unit is valid, an error code otherwise
      */
-    OFCondition checkMeasurementUnit(const DSRCodedEntryValue &measurementUnit) const;
+    virtual OFCondition checkMeasurementUnit(const DSRCodedEntryValue &measurementUnit) const;
 
     /** check the specified numeric value qualifier for validity.
-     *  Internally, the methods DSRCodedEntryValue::isEmpty() and
-     *  DSRCodedEntryValue::checkCurrentValue() are used for this purpose.  Conformance
-     *  with the Context Group 42 (as defined in the DICOM standard) is not yet checked.
+     *  Internally, DSRCodedEntryValue::isEmpty() and DSRCodedEntryValue::checkCurrentValue()
+     *  are used for this purpose.  Conformance with the Context Group 42 (as defined in the
+     *  DICOM standard) is not checked; see class CMR_SRNumericMeasurementValue if needed,
+     *  which supports such additional checks.
      ** @param  valueQualifier  numeric value qualifier to be checked
      ** @return status, EC_Normal if value qualifier is valid, an error code otherwise
      */
-    OFCondition checkNumericValueQualifier(const DSRCodedEntryValue &valueQualifier) const;
+    virtual OFCondition checkNumericValueQualifier(const DSRCodedEntryValue &valueQualifier) const;
 
     /** check the specified rational representation for validity.
      *  The only check that is performed is that the 'rationalDenominator' is not zero, i.e.
@@ -464,21 +523,21 @@ class DCMTK_DCMSR_EXPORT DSRNumericMeasurementValue
      *  @param  rationalDenominator  denominator of a rational representation to be checked
      ** @return status, EC_Normal if rational representation is valid, an error code otherwise
      */
-    OFCondition checkRationalRepresentation(const Sint32 rationalNumerator,
-                                            const Uint32 rationalDenominator) const;
+    virtual OFCondition checkRationalRepresentation(const Sint32 rationalNumerator,
+                                                    const Uint32 rationalDenominator) const;
 
     /** check the currently stored numeric measurement value for validity.
      *  See above checkXXX() methods for details.
      ** @return status, EC_Normal if current value is valid, an error code otherwise
      */
-    OFCondition checkCurrentValue() const;
+    virtual OFCondition checkCurrentValue() const;
 
 
   private:
 
-    /// Numeric Value (VR=DS, type 1)
+    /// Numeric Value (VR=DS, type 1 within a type 2 sequence)
     OFString               NumericValue;
-    /// Measurement Unit (type 2)
+    /// Measurement Unit (type 1 within a type 2 sequence)
     DSRCodedEntryValue     MeasurementUnit;
     /// Numeric Value Qualifier (type 3)
     DSRCodedEntryValue     ValueQualifier;
@@ -491,4 +550,16 @@ class DCMTK_DCMSR_EXPORT DSRNumericMeasurementValue
 };
 
 
+/** output stream operator for numeric measurement values.
+ *  Internally, the DSRNumericMeasurementValue::print() method is used, i.e. the output
+ *  looks like this: "3.5" (cm,UCUM[1.4],"centimeter") or "empty" (if the value is empty)
+ *  @param  stream              output stream to which the numeric measurement value is
+ *                              printed
+ *  @param  numericMeasurement  numeric measurement value to be printed
+ *  @return reference to output stream
+ */
+DCMTK_DCMSR_EXPORT STD_NAMESPACE ostream &operator<<(STD_NAMESPACE ostream &stream,
+                                                     const DSRNumericMeasurementValue &numericMeasurement);
+
+
 #endif
