@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2016, OFFIS e.V.
+ *  Copyright (C) 2000-2019, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -244,7 +244,7 @@ class DCMTK_DCMSR_EXPORT DSRTypes
 
   // --- constant declarations ---
 
-    /** @name read() flags.
+    /** @name read() flags
      *  These flags can be combined and passed to the read() methods.
      *  The 'shortcut' flags can be used for common combinations.
      */
@@ -273,7 +273,7 @@ class DCMTK_DCMSR_EXPORT DSRTypes
     //@}
 
 
-    /** @name renderHTML() flags.
+    /** @name renderHTML() flags
      *  These flags can be combined and passed to the renderHMTL() methods.
      *  Please note that only the 'external' flags can be used from outside
      *  this library.  The 'shortcut' flags can be used for common combinations.
@@ -354,7 +354,7 @@ class DCMTK_DCMSR_EXPORT DSRTypes
     //@}
 
 
-    /** @name read/writeXML() flags.
+    /** @name read/writeXML() flags
      *  These flags can be combined and passed to the read/writeXML() methods.
      *  The 'shortcut' flags can be used for common combinations.
      */
@@ -396,6 +396,9 @@ class DCMTK_DCMSR_EXPORT DSRTypes
     /// write: add comments with details at beginning/end of included template (might be useful for debugging purposes)
     static const size_t XF_addCommentsForIncludedTemplate;
 
+    /// read: accept empty Study/Series/SOP Instance UID attribute values (must be filled later)
+    static const size_t XF_acceptEmptyStudySeriesInstanceUID;
+
     /// shortcut: combines all XF_xxxAsAttribute write flags (see above)
     static const size_t XF_encodeEverythingAsAttribute;
     //@}
@@ -452,6 +455,9 @@ class DCMTK_DCMSR_EXPORT DSRTypes
     /// do not count internal "included template" nodes (only with PF_hideIncludedTemplateNodes)
     static const size_t PF_dontCountIncludedTemplateNodes;
 
+    /// print text "empty code" for empty codes (instead of "invalid code")
+    static const size_t PF_printEmptyCodes;
+
     /// shortcut: print all codes (combines all PF_printXxxCodes flags, see above)
     static const size_t PF_printAllCodes;
     //@}
@@ -529,8 +535,16 @@ class DCMTK_DCMSR_EXPORT DSRTypes
         DT_ExtensibleSR,
         /// DICOM IOD: Acquisition Context SR
         DT_AcquisitionContextSR,
+        /// DICOM IOD: Simplified Adult Echo SR
+        DT_SimplifiedAdultEchoSR,
+        /// DICOM IOD: Patient Radiation Dose SR
+        DT_PatientRadiationDoseSR,
+        /// DICOM IOD: Performed Imaging Agent Administration SR
+        DT_PerformedImagingAgentAdministrationSR,
+        /// DICOM IOD: Planned Imaging Agent Administration SR
+        DT_PlannedImagingAgentAdministrationSR,
         /// internal type used to mark the last entry
-        DT_last = DT_AcquisitionContextSR
+        DT_last = DT_PlannedImagingAgentAdministrationSR
     };
 
     /** SR relationship types
@@ -623,12 +637,20 @@ class DCMTK_DCMSR_EXPORT DSRTypes
         PT_Blending,
         /// XA/XRF Grayscale Softcopy Presentation State (XGSPS)
         PT_XAXRFGrayscale,
-        /// Grayscale Planar MPR Volumetric Presentation State (GPVPS)
+        /// Grayscale Planar MPR Volumetric Presentation State (GP-VPS)
         PT_GrayscalePlanarMPR,
-        /// Compositing Planar MPR Volumetric Presentation State (CPVPS)
+        /// Compositing Planar MPR Volumetric Presentation State (CP-VPS)
         PT_CompositingPlanarMPR,
+        /// Advanced Blending Presentation State (ABPS)
+        PT_AdvancedBlending,
+        /// Volume Rendering Volumetric Presentation State (VR-VPS)
+        PT_VolumeRendering,
+        /// Segmented Volume Rendering Volumetric Presentation State (SVR-VPS)
+        PT_SegmentedVolumeRendering,
+        /// Multiple Volume Rendering Volumetric Presentation State (MVR-VPS)
+        PT_MultipleVolumeRendering,
         /// internal type used to mark the last entry
-        PT_last = PT_CompositingPlanarMPR
+        PT_last = PT_MultipleVolumeRendering
     };
 
     /** SR graphic types.  Used for content item SCOORD.
@@ -877,6 +899,18 @@ class DCMTK_DCMSR_EXPORT DSRTypes
      */
     static OFBool requiresEnhancedEquipmentModule(const E_DocumentType documentType);
 
+    /** check whether SR document type requires Timezone Module
+     ** @param  documentType  SR document type to be checked
+     ** @return OFTrue if Timezone Module is required, OFFalse otherwise
+     */
+    static OFBool requiresTimezoneModule(const E_DocumentType documentType);
+
+    /** check whether SR document type requires Synchronization Module
+     ** @param  documentType  SR document type to be checked
+     ** @return OFTrue if Synchronization Module is required, OFFalse otherwise
+     */
+    static OFBool requiresSynchronizationModule(const E_DocumentType documentType);
+
     /** convert relationship type to DICOM defined term
      ** @param  relationshipType  relationship type to be converted
      ** @return defined term if type is valid, empty string otherwise (never NULL)
@@ -1095,7 +1129,6 @@ class DCMTK_DCMSR_EXPORT DSRTypes
     static const OFString &currentDate(OFString &dateString);
 
     /** get current time in DICOM 'TM' format. (HHMMSS)
-     *  The optional UTC notation (e.g. +0100) is currently not supported.
      ** @param  timeString  string used to store the current time
      *                      ('000000' if current time could not be retrieved)
      ** @return resulting character string (see 'timeString')
@@ -1112,6 +1145,13 @@ class DCMTK_DCMSR_EXPORT DSRTypes
      */
     static const OFString &currentDateTime(OFString &dateTimeString);
 
+    /** get local timezone in DICOM format. (&ZZXX)
+     ** @param  timezoneString  string used to store the local timezone
+     *                          ('+0000' if timezone could not be retrieved)
+     ** @return resulting character string (see 'timezoneString')
+     */
+    static const OFString &localTimezone(OFString &timezoneString);
+
     /** convert DICOM date string to readable format.
      *  The ISO format "YYYY-MM-DD" is used for the readable format.
      ** @param  dicomDate     date in DICOM DA format (YYYYMMDD)
