@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2015-2018, J. Riesmeier, Oldenburg, Germany
+ *  Copyright (C) 2015-2019, J. Riesmeier, Oldenburg, Germany
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation are maintained by
@@ -32,7 +32,7 @@
 #include "dcmtk/dcmsr/dsrnumvl.h"
 #include "dcmtk/dcmsr/dsrnumtn.h"
 #include "dcmtk/dcmsr/codes/dcm.h"
-#include "dcmtk/dcmsr/codes/srt.h"
+#include "dcmtk/dcmsr/codes/sct.h"
 #include "dcmtk/dcmsr/codes/ucum.h"
 #include "dcmtk/dcmsr/cmr/init.h"
 #include "dcmtk/dcmsr/cmr/logger.h"
@@ -87,7 +87,7 @@ OFTEST(dcmsr_CID244e_Laterality)
     CID244e_Laterality ctxGroup;
     DSRCodedEntryValue codedEntry;
     OFCHECK(!ctxGroup.hasSelectedValue());
-    OFCHECK_EQUAL(ctxGroup.mapImageLaterality("R").getCodeValue(), "G-A100");
+    OFCHECK_EQUAL(ctxGroup.mapImageLaterality("R").getCodeValue(), "24028007");
     OFCHECK(ctxGroup.mapImageLaterality("B", codedEntry).good());
     OFCHECK(ctxGroup.selectValue("L").good());
     OFCHECK(DSRCodedEntryValue(ctxGroup).getCodeMeaning() == "Left");
@@ -236,7 +236,7 @@ OFTEST(dcmsr_TID1411_VolumetricROIMeasurements)
     OFCHECK(!volumetric.isValid());
     /* do more sophisticated tests */
     CMR_TID1419_in_TID1411_in_TID1500 &measurement = volumetric.getMeasurement();
-    OFCHECK(volumetric.addFindingSite(DSRBasicCodedEntry("EFGH", "99TEST", "Finding Site"), CMR_CID244::RightAndLeft).good());
+    OFCHECK(volumetric.addFindingSite(DSRBasicCodedEntry("EFGH", "99TEST", "Finding Site"), CMR_CID244::Bilateral).good());
     OFCHECK(!volumetric.hasMeasurements());
     OFCHECK(!measurement.hasMeasurement());
     OFCHECK(measurement.createNewMeasurement(CMR_CID7469::Volume, CMR_TID1419_in_TID1411_in_TID1500::MeasurementValue("15", CMR_CID7181::CubicMillimeter)).good());
@@ -348,7 +348,7 @@ OFTEST(dcmsr_TID1500_MeasurementReport)
     OFCHECK(volMeasurements.setRealWorldValueMap(DSRCompositeReferenceValue(UID_RealWorldValueMappingStorage, "2.0.3.0.4.0")).good());
     OFCHECK(volMeasurements.setRealWorldValueMap(DSRCompositeReferenceValue(UID_CTImageStorage, "2.0")).bad());
     OFCHECK(volMeasurements.setRealWorldValueMap(dataset).good());
-    OFCHECK(volMeasurements.addFindingSite(CODE_SRT_AorticArch).good());
+    OFCHECK(volMeasurements.addFindingSite(CODE_SCT_AorticArch).good());
     OFCHECK(volMeasurements.setMeasurementMethod(DSRCodedEntryValue(CODE_DCM_SUVBodyWeightCalculationMethod)).good());
     OFCHECK(!volMeasurements.isValid());
     /* add two measurement values */
