@@ -342,6 +342,19 @@ alloc_ptd ()
 void initializeFactoryRegistry();
 
 
+#ifdef DCMTK_LOG4CPLUS_USE_WIN32_THREADS
+
+//! Thread local storage clean up function for WIN32 threads.
+static
+void WINAPI
+ptd_cleanup_func_win32(void * /* arg */ )
+{
+    threadCleanup();
+}
+
+#endif
+
+
 //! Thread local storage clean up function for POSIX threads.
 static
 void
@@ -405,7 +418,11 @@ void initializeLog4cplus()
     if (initialized)
         return;
 
-    internal::tls_storage_key = thread::impl::tls_init (ptd_cleanup_func);
+#ifdef DCMTK_LOG4CPLUS_USE_WIN32_THREADS
+    internal::tls_storage_key = thread::impl::tls_init(ptd_cleanup_func_win32);
+#else
+    internal::tls_storage_key = thread::impl::tls_init(ptd_cleanup_func);
+#endif
     threadSetup ();
 
     DefaultContext * dc = get_dc (true);
