@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2011, OFFIS e.V.
+ *  Copyright (C) 2011-2019, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were slightly modified by
@@ -61,7 +61,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * @version     V2.43
+ * @version     V2.44
  * @author      Frank Vanden Berghen
  *
  * \section tutorial First Tutorial
@@ -144,12 +144,13 @@
 #include "dcmtk/ofstd/ofstdinc.h"
 #include "dcmtk/ofstd/ofdefine.h"
 
-#ifdef _UNICODE
+// DCMTK: we might want to enable wide characters without the "official" defines
+#if defined(UNICODE) || defined(_UNICODE) || defined(WIDE_CHAR_XML_PARSER)
 // If you comment the next "define" line then the library will never "switch to" _UNICODE (wchar_t*) mode (16/32 bits per characters).
 // This is useful when you get error messages like:
 //    'XMLNode::openFileHelper' : cannot convert parameter 2 from 'const char [5]' to 'const wchar_t *'
-// The _XMLWIDECHAR preprocessor variable force the XMLParser library into either utf16/32-mode (the proprocessor variable
-// must be defined) or utf8-mode(the pre-processor variable must be undefined).
+// The _XMLWIDECHAR preprocessor variable force the XMLParser library into either utf16/32-mode (the preprocessor variable
+// must be defined) or utf8-mode (the pre-processor variable must be undefined).
 #define _XMLWIDECHAR
 #endif
 
@@ -161,9 +162,11 @@
 // DCMTK: Simplified to use our own version in ofstd
 #define XMLDLLENTRY DCMTK_OFSTD_EXPORT
 
+// DCMTK: we don't want wide characters on other systems than Windows
+#if !defined(_XMLWINDOWS) || !defined(_XMLWIDECHAR)
 // uncomment the next line if you want no support for wchar_t* (no need for the <wchar.h> or <tchar.h> libraries anymore to compile)
-// DCMTK: we don't want wide characters
 #define XML_NO_WIDE_CHAR
+#endif
 
 #ifdef XML_NO_WIDE_CHAR
 // DCMTK: we definitely need the following define on Windows systems
@@ -321,7 +324,7 @@ typedef struct XMLDLLENTRY XMLNode
     /// Parse an XML file and return the root of a XMLNode tree representing the file. A very crude error checking is made. An attempt to guess the Char Encoding used in the file is made.
     static XMLNode openFileHelper(XMLCSTR     filename, XMLCSTR tag=NULL);
     /**< The "openFileHelper" function reports to the screen all the warnings and errors that occurred during parsing of the XML file.
-     * This function also tries to guess char Encoding (UTF-8, ASCII or SHIT-JIS) based on the first 200 bytes of the file. Since each
+     * This function also tries to guess char Encoding (UTF-8, ASCII or SHIFT-JIS) based on the first 200 bytes of the file. Since each
      * application has its own way to report and deal with errors, you should rather use the "parseFile" function to parse XML files
      * and program yourself thereafter an "error reporting" tailored for your needs (instead of using the very crude "error reporting"
      * mechanism included inside the "openFileHelper" function).
@@ -683,25 +686,26 @@ XMLDLLENTRY XMLSTR stringDup(XMLCSTR source, int cbData=-1);
 XMLDLLENTRY void freeXMLString(XMLSTR t); // {free(t);}
 /** @} */
 
-// DCMTK: currently, these functions are not needed
-#if 0
 /** @defgroup atoX ato? like functions
  * @ingroup XMLParserGeneral
- * The "xmlto?" functions are equivalents to the atoi, atol, atof functions.
+ * The "xmlto?" functions are equivalents to the atoi, atol, atoll, atof functions.
  * The only difference is: If the variable "xmlString" is NULL, than the return value
- * is "defautValue". These 6 functions are only here as "convenience" functions for the
+ * is "defautValue". These 7 functions are only here as "convenience" functions for the
  * user (they are not used inside the XMLparser). If you don't need them, you can
  * delete them without any trouble.
  *
  * @{ */
-XMLDLLENTRY char    xmltob(XMLCSTR xmlString,char   defautValue=0);
-XMLDLLENTRY int     xmltoi(XMLCSTR xmlString,int    defautValue=0);
-XMLDLLENTRY long    xmltol(XMLCSTR xmlString,long   defautValue=0);
-XMLDLLENTRY double  xmltof(XMLCSTR xmlString,double defautValue=.0);
-XMLDLLENTRY XMLCSTR xmltoa(XMLCSTR xmlString,XMLCSTR defautValue=_CXML(""));
-XMLDLLENTRY XMLCHAR xmltoc(XMLCSTR xmlString,const XMLCHAR defautValue=_CXML('\0'));
-/** @} */
+XMLDLLENTRY char      xmltob (XMLCSTR xmlString,char      defautValue=0);
+XMLDLLENTRY int       xmltoi (XMLCSTR xmlString,int       defautValue=0);
+XMLDLLENTRY long      xmltol (XMLCSTR xmlString,long      defautValue=0);
+// DCMTK adds xmltoll() in addition to xmltol()
+#if defined(HAVE_LONG_LONG) && (defined(HAVE_ATOLL) || defined (_XMLWINDOWS))
+XMLDLLENTRY long long xmltoll(XMLCSTR xmlString,long long defautValue=0);
 #endif
+XMLDLLENTRY double    xmltof (XMLCSTR xmlString,double    defautValue=.0);
+XMLDLLENTRY XMLCSTR   xmltoa (XMLCSTR xmlString,XMLCSTR   defautValue=_CXML(""));
+XMLDLLENTRY XMLCHAR   xmltoc (XMLCSTR xmlString,const XMLCHAR defautValue=_CXML('\0'));
+/** @} */
 
 /** @defgroup ToXMLStringTool Helper class to create XML files using "printf", "fprintf", "cout",... functions.
  * @ingroup XMLParserGeneral
