@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2011-2016, OFFIS e.V.
+ *  Copyright (C) 2011-2019, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -27,11 +27,8 @@
 #include "dcmtk/ofstd/ofdiag.h"
 #include "dcmtk/ofstd/ofconsol.h"
 
-BEGIN_EXTERN_C
-#ifdef HAVE_SYS_ERRNO_H
-#include <sys/errno.h>
-#endif
-END_EXTERN_C
+#define INCLUDE_CERRNO
+#include "dcmtk/ofstd/ofstdinc.h"
 
 #ifdef HAVE_WINDOWS_H
 #define WIN32_LEAN_AND_MEAN
@@ -55,6 +52,18 @@ const unsigned int OFCharacterEncoding::CPC_UTF8   = CP_UTF8;
 
 #ifdef DCMTK_ENABLE_CHARSET_CONVERSION
 #if DCMTK_ENABLE_CHARSET_CONVERSION == DCMTK_CHARSET_CONVERSION_ICU
+
+// Workaround for ICU. Type char16_t is only supported since C++11.
+#ifndef HAVE_CHAR16_T
+#define UCHAR_TYPE uint16_t
+#endif
+
+// Another Workaround for ICU. DCMTK does not use exceptions.
+// If U_NOEXCEPT is not defined, ICU falls back to NOEXCEPT.
+#ifndef HAVE_CXX11
+#define U_NOEXCEPT
+#endif
+
 #include <unicode/ucnv.h>
 #include <unicode/ucnv_err.h>
 
