@@ -27,15 +27,12 @@
 #include "dcmtk/ofstd/ofchrenc.h"
 
 
-static void checkConversionFlags(OFCharacterEncoding& charEnc,
-                                 const unsigned flags)
-{
-    if (OFCharacterEncoding::supportsConversionFlags(flags))
-    {
-        OFCHECK(charEnc.setConversionFlags(flags).good());
-        OFCHECK_EQUAL(charEnc.getConversionFlags(), flags);
+#define checkConversionFlags(flags)\
+    if (OFCharacterEncoding::supportsConversionFlags(flags))\
+    {\
+        OFCHECK(charEnc.setConversionFlags(flags).good());\
+        OFCHECK_EQUAL(charEnc.getConversionFlags(), flags);\
     }
-}
 
 
 OFTEST(ofstd_OFCharacterEncoding_1)
@@ -64,14 +61,23 @@ OFTEST(ofstd_OFCharacterEncoding_1)
         OFCHECK_EQUAL(resultStr, OFString(" \0 ", 3));
         OFCHECK(charEnc.selectEncoding("ASCII", "DCMTK").bad());
         OFCHECK(charEnc.selectEncoding("DCMTK", "ASCII").bad());
-        OFCHECK(charEnc.selectEncoding("", "ASCII").good());
-        OFCHECK(charEnc.selectEncoding("ASCII", "").good());
-        OFCHECK(charEnc.selectEncoding("ASCII", charEnc.getLocaleEncoding()).good());
-        checkConversionFlags(charEnc, OFCharacterEncoding::AbortTranscodingOnIllegalSequence);
-        checkConversionFlags(charEnc, OFCharacterEncoding::DiscardIllegalSequences);
-        checkConversionFlags(charEnc, OFCharacterEncoding::TransliterateIllegalSequences);
-        checkConversionFlags(charEnc, OFCharacterEncoding::TransliterateIllegalSequences
-                                    | OFCharacterEncoding::DiscardIllegalSequences);
+        // some implementations of iconv_open() in the C standard library do
+        // not understand the "" argument
+        if (OFCharacterEncoding::hasDefaultEncoding())
+        {
+            OFCHECK(charEnc.selectEncoding("", "ASCII").good());
+            OFCHECK(charEnc.selectEncoding("ASCII", "").good());
+            OFCHECK(charEnc.selectEncoding("ASCII", charEnc.getLocaleEncoding()).good());
+        }
+        else
+        {
+            OFCHECK(charEnc.selectEncoding("ASCII", "UTF-8").good());
+        }
+        checkConversionFlags(OFCharacterEncoding::AbortTranscodingOnIllegalSequence);
+        checkConversionFlags(OFCharacterEncoding::DiscardIllegalSequences);
+        checkConversionFlags(OFCharacterEncoding::TransliterateIllegalSequences);
+        checkConversionFlags(OFCharacterEncoding::TransliterateIllegalSequences
+                             | OFCharacterEncoding::DiscardIllegalSequences);
         charEnc.clear();
         OFCHECK(charEnc.convertString("Simple Text", resultStr).bad());
     }
